\name{chol.reduce}
\alias{chol.reduce}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Incomplete Cholesky decomposition}
\description{
  \code{chol.reduce} computes the incomplete Cholesky decomposition
  of the kernel matrix from a data matrix. 
}
\usage{
chol.reduce(x, kernel="rbfdot", kpar=list(sigma=0.1), tol = 0.001, max.iter = dim(x)[1], verbose = 0)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{The data matrix indexed by row}
  \item{kernel}{the kernel function used in training and predicting.
    This parameter can be set to any function, of class kernel, which computes a dot product between two
    vector arguments. kernlab provides the most popular kernel functions
    which can be used by setting the kernel parameter to the following
    strings:
    \itemize{
      \item \code{rbfdot} Radial Basis kernel function "Gaussian"
      \item \code{polydot} Polynomial kernel function
      \item \code{vanilladot} Linear kernel function
      \item \code{tanhdot} Hyperbolic tangent kernel function
      \item \code{laplacedot} Laplacian kernel function
      \item \code{besseldot} Bessel kernel function
      \item \code{anovadot} ANOVA RBF kernel function
    }
    The kernel parameter can also be set to a user defined function of
    class kernel by passing the function name as an argument.
  }

  \item{kpar}{the list of hyper-parameters (kernel parameters).
    This is a list which contains the parameters to be used with the
    kernel function. For valid parameters for existing kernels are :
    \itemize{
      \item \code{sigma} inverse kernel width for the Radial Basis
      kernel function "rbfdot" and the Laplacian kernel "laplacedot".
      \item \code{degree, scale, offset} for the Polynomial kernel "polydot"
      \item \code{scale, offset} for the Hyperbolic tangent kernel
      function "tanhdot"
      \item \code{sigma, order, degree} for the Bessel kernel "besseldot". 
      \item \code{sigma, degree} for the ANOVA kernel "anovadot".
    }
    Hyper-parameters for user defined kernels can be passed through the
    kpar parameter as well.
  }
  
  \item{tol}{algorithm stops when remaining pivots bring less accuracy
    then \code{tol} (default: 0.001)}
  \item{max.iter}{maximum number of iterations }
  \item{verbose}{print info on algorithm convergence }
}
\details{An incomplete cholesky decomposition calculates
  \eqn{Z} where \eqn{K= ZZ'} \eqn{K} being the kernel matrix.
  Since the rank of a kernel matrix is usually low, \eqn{Z} tends to be smaller
  then the complete kernel matrix. The decomposed matrix can be
  used to create memory efficient kernel-based algorithms without the
  need to compute and store a complete kernel matrix in memory.}
\value{
  An S4 object of class "inc.chol" which is an extension of the class
  "matrix". The object is the decomposed kernel matrix along with 
  the slots :
  \item{pivots}{Indices on which pivots where done}
  \item{diag.residues}{Residuals left on the diagonal}
  \item{maxresiduals}{Residuals picked for pivoting}

  slots can be accessed either by \code{object@slot}
or by accessor functions with the same name (e.g. \code{pivots(object))}}
\references{ \item
      Francis R. Bach, Michael I. Jordan\cr
      \emph{Kernel Independent Component Analysis}\cr
      Journal of Machine Learning Research  3, 1-48\cr
      \url{http://www.jmlr.org/papers/volume3/bach02a/bach02a.pdf}
    }
 }
\author{Alexandros Karatzoglou (based on Matlab code by 
  S.V.N. (Vishy) Vishwanathan and Alex Smola)\cr
\email{alexandros.karatzoglou@ci.tuwien.ac.at}}

\seealso{\code{\link{chol}}}
\examples{

data(iris)
datamatrix <- as.matrix(iris[,-5])
# initialize kernel function
rbf <- rbfdot(sigma=0.1)
rbf
Z <- chol.reduce(datamatrix,kernel=rbf)
dim(Z)
pivots(Z)
# calculate kernel matrix
K <- crossprod(t(Z))
# difference between approximated and real kernel matrix
(K - kernelMatrix(kernel=rbf, datamatrix))[6,]

}
\keyword{algebra}
\keyword{array}

\eof
\name{couple}
\alias{couple}

\title{Probabilities Coupling function}
\description{
  \code{couple} is used to link class-probability estimates produced by
   pairwise coupling  in multi-class classification problems.
}
\usage{
couple(probin, coupler = "minpair")
}

\arguments{
  \item{probin}{ The pairwise coupled class-probability estimates}
  \item{coupler}{The type of coupler to use. Currently \code{minpar} and
    \code{pkpd} and \code{vote} are supported (see reference for more
    details).
  If \code{vote} is selected the returned value is a primitive estimate
  passed on given votes.}
  
}
\details{
  As binary classification problems are much easier to solve many
  techniques exist to decompose multi-class classification problems into
  many binary classification problems (voting, error codes,
  etc.). Pairwise coupling (one against one) constructs a rule for
  discriminating between every pair of classes and then selecting the
  class
  with the most winning two-class decisions. As many classification
  methods return class probability estimates techniques for combining
  these results are needed.
    
}
\value{
  A matrix with the resulting probability estimates. 
}
\references{
  Ting-Fan Wu, Chih-Jen Lin, ruby C. Weng\cr
  \emph{Probability Estimates for Multi-class Classification by Pairwise
    Coupling}\cr
  Neural Information Processing Symposium 2003
  \url{http://books.nips.cc/papers/files/nips16/NIPS2003_0538.pdf}
  }
\author{Alexandros Karatzoglou \cr \email{alexandros.karatzoglou@ci.tuwien.ac.at} }


 

\seealso{ \code{\link{predict.ksvm}}, \code{\link{ksvm}}}
\examples{
## create artificial pairwise probabilities
pairs <- matrix(c(0.82,0.12,0.76,0.1,0.9,0.05),2)

couple(pairs)

couple(pairs, coupler="pkpd")

couple(pairs, coupler ="vote")
}
\keyword{classif}


\eof
\name{dots}
\alias{dots}
\alias{rbfdot}
\alias{polydot}
\alias{tanhdot}
\alias{vanilladot}
\alias{laplacedot}
\alias{besseldot}
\alias{anovadot}
\alias{kpar}
\alias{show,kernel-method}
\title{Kernel Functions}
\description{
  The kernel generating functions provided in kernlab. \cr
  The Gaussian kernel \eqn{k(x,x') = \exp(-\sigma \|x - x'\|^2)} \cr
  the Polynomial kernel \eqn{k(x,x') = (scale <x, x'> + offset)^degree}.\cr
  the Linear kernel \eqn{k(x,x') = <x, x'>}\cr
  the  Hyperbolic tangent kernel \eqn{k(x, x') = \tanh(scale <x, x'> +
    offset)}
  the Laplacian kernel \eqn{k(x,x') = \exp(-\sigma \|x - x'\|)} \cr
  the Bessel kernel \eqn{k(x,x') = (- Bessel_{(\nu+1)}^n sigma \|x - x'\|^2)} \cr
  the ANOVA RBF kernel \eqn{k(x,x') = \sum_{1\leq i_1 \ldots < i_D \leq
      N} \prod_{d=1}^D k(x_{id}, {x'}_{id})} where k(x,x) is a RBF kernel. 
}
\usage{
rbfdot(sigma = 1)

polydot(degree = 1, scale = 1, offset = 1)

tanhdot(scale = 1, offset = 1)

vanilladot()

laplacedot(sigma = 1)

besseldot(sigma = 1, order = 1, degree = 1)

anovadot(sigma = 1, degree = 1)
}

\arguments{
  \item{sigma}{The inverse kernel width used by the Gaussian the
    Laplacian, the Bessel and the ANOVA kernel }
  \item{degree}{The degree of the polynomial, bessel or ANOVA
    kernel function. This has to be an integer.}
  \item{scale}{The scaling parameter of the polynomial and tangent
    kernel is a convenient way of normalizing
    patterns without the need to modify the data itself}
  \item{offset}{The offset used in a polynomial or hyperbolic tangent
    kernel}
  \item{order}{The order of the Bessel function to be used as a kernel}
}
\details{
  The kernel generating function are used to initialize a kernel
  function
  which calculates the dot (inner) product between two feature vectors in a
  Hilbert Space. These functions can be based as a \code{kernel} argument on almost all
  functions in kernlab (eg. \code{ksvm}, \code{kpca}  etc).
  Although using one of the above mentioned existing kernel functions as a
  \code{kernel} argument in various functions in kernlab has the
  advantage that use of optimize kernel utilities methods are used
  any other function implementing a dot product of class kernel can also be used as a kernel
  argument. This allows the user to use test an develop special kernels
  for a given data set and algorithm.
  }
\value{
 Return an S4 object of class \code{kernel} which extents the
 \code{function} class. The resulting function implements the given
 kernel calculating the inner (dot) product between two vectors.
 \item{kpar}{a list containing the kernel parameters (hyperparameters)
   used.}
 the kernel parameters can be accessed by the \code{kpar} function.
 }

\author{Alexandros Karatzoglou\cr
  \email{alexandros.karatzoglou@ci.tuwien.ac.at}}

\note{If the offset in the Polynomial kernel is set to $0$, we obtain homogeneous polynomial
  kernels, for positive values, we have inhomogeneous
  kernels. Note that for negative values the kernel does not satisfy Mercer's
  condition and thus the optimizers may fail. \cr

  In the Hyperbolic tangent kernel if the offset is negative the likelihood of obtaining a kernel
  matrix that is not positive definite is much higher (since then even some
  diagonal elements may be negative), hence if this kernel has to be used, the
  offset should always be positive. Note, however, that this is no guarantee
  that the kernel will be positive.
}




\seealso{ \code{\link{kernelMatrix} }, \code{\link{kernelMult}}, \code{\link{kernelPol}}}
\examples{
rbfkernel <- rbfdot(sigma = 0.1)
rbfkernel

kpar(rbfkernel)

## create two vectors
x <- rnorm(10)
y <- rnorm(10)

## calculate dot product
rbfkernel(x,y)

}
\keyword{symbolmath}


\eof
\name{gausspr-class}
\docType{class}
\alias{gausspr-class}
\alias{alpha,gausspr-method}
\alias{cross,gausspr-method}
\alias{error,gausspr-method}
\alias{fit,gausspr-method}
\alias{kcall,gausspr-method}
\alias{kernelf,gausspr-method}
\alias{kpar,gausspr-method}
\alias{lev,gausspr-method}
\alias{type,gausspr-method}
\alias{alphaindex,gausspr-method}
\alias{xmatrix,gausspr-method}
\alias{ymatrix,gausspr-method}

\title{Class "gausspr"}
\description{The Gaussian Processes object }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("gausspr", ...)}.
    or by calling the \code{gausspr} function 
}
\section{Slots}{
  \describe{
    \item{\code{tol}:}{Object of class \code{"numeric"} contains
      tolerance of termination criteria}
    \item{\code{kernelf}:}{Object of class \code{"function"} contains
      the kernel function used}
    \item{\code{kpar}:}{Object of class \code{"list"} contains the
      kernel parameter used }
    \item{\code{kcall}:}{Object of class \code{"ANY"} contains the used
      function call }
    \item{\code{type}:}{Object of class \code{"character"} contains
      type of problem }
    \item{\code{kterms}:}{Object of class \code{"ANY"} contains the
      terms representation of the symbolic model used (when using a formula)}}
    \item{\code{xmatrix}:}{Object of class \code{"matrix"} containing
      the data matrix used }
    \item{\code{ymatrix}:}{Object of class \code{"ANY"} containing the
      response matrix}
    \item{\code{fit}:}{Object of class \code{"ANY"} containing the
      fitted values  }
    \item{\code{lev}:}{Object of class \code{"vector"} containing the
      levels of the response (in case of classification) }
    \item{\code{nclass}:}{Object of class \code{"numeric"} containing
      the number of classes (in case of classification) }
    \item{\code{alpha}:}{Object of class \code{"ANY"} containing the
      computes alpha values }
    \item{\code{alphaindex}}{Object of class \code{"list"} containing
      the indexes for the alphas in various classes (in multi-class problems).}
    \item{\code{nvar}:}{Object of class \code{"numeric"} containing the
      computed variance}
    \item{\code{error}:}{Object of class \code{"numeric"} containing the
    training error}
    \item{\code{cross}:}{Object of class \code{"numeric"} containing the
    cross validation error}
    \item{\code{n.action}:}{Object of class \code{"ANY"} containing the
      action performed in NA }
  }
}
\section{Methods}{
  \describe{ 
    \item{alpha}{\code{signature(object = "gausspr")}: returns the alpha
    vector}
  \item{cross}{\code{signature(object = "gausspr")}: returns the cross
    validation error }
    \item{error}{\code{signature(object = "gausspr")}: returns the
      training error }
    \item{fit}{\code{signature(object = "gausspr")}: returns the fitted values }
    \item{kcall}{\code{signature(object = "gausspr")}: returns the call performed}
    \item{kernelf}{\code{signature(object = "gausspr")}: returns the
      kernel function used}
    \item{kpar}{\code{signature(object = "gausspr")}: returns the kernel
    parameter used}
    \item{lev}{\code{signature(object = "gausspr")}: returns the
      response levels (in classification) }
    \item{type}{\code{signature(object = "gausspr")}: returns the type
      of problem}
    \item{xmatrix}{\code{signature(object = "gausspr")}: returns the
      data matrix used}
    \item{ymatrix}{\code{signature(object = "gausspr")}: returns the
      response matrix used}
  }
}

\author{Alexandros Karatzoglou\cr \email{alexandros.karatzoglou@ci.tuwien.ac.at}}



\seealso{
  \code{\link{gausspr}}, 
  \code{\link{ksvm-class}}
}
\examples{

# train model
data(iris)
test <- gausspr(Species~.,data=iris,var=2)
test
alpha(test)
error(test)
lev(test)
}
\keyword{classes}

\eof
\name{gausspr}
\alias{gausspr}
\alias{gausspr,formula-method}
\alias{gausspr,vector-method}
\alias{gausspr,matrix-method}
\alias{show,gausspr-method}
\alias{predict,gausspr-method}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Gaussian processes for regression and classification}
\description{
  \code{gausspr} is an implementation of Gaussian processes.
  Gaussian processes can be used for classification and regression.
  
 }
\usage{

\S4method{gausspr}{formula}(x, data=NULL, ..., subset, na.action = na.omit)

\S4method{gausspr}{vector}(x,...)

\S4method{gausspr}{matrix}(x, y, type="classification", kernel="rbfdot", kpar=list(sigma = 0.1),
var=1, tol=0.001, cross=0, fit=TRUE, ... , subset, na.action = na.omit)


}
%- maybe also 'usage' for other objects documented here.
\arguments{

\item{x}{a symbolic description of the model to be fit or a matrix or
  vector when a formula interface is not used. Note, that an when using
  the formula interface, that an intercept is always included, whether
  given in the formula or not.
  When not using a formula x is a matrix or vector
	  containg the variables in the model} 
	   
  \item{data}{an optional data frame containing the variables in the model.
          By default the variables are taken from the environment which
          `gausspr' is called from.}
	  
  \item{y}{a response vector with one label for each row/component of \code{x}. Can be either
    a factor (for classification tasks) or a numeric vector (for
    regression).}
  \item{type}{Type of problem. Either "classification" or "regression"}

 \item{kernel}{the kernel function used in training and predicting.
    This parameter can be set to any function, of class kernel, which computes a dot product between two
    vector arguments. kernlab provides the most popular kernel functions
    which can be used by setting the kernel parameter to the following
    strings:
    \itemize{
      \item \code{rbfdot} Radial Basis kernel function "Gaussian"
      \item \code{polydot} Polynomial kernel function
      \item \code{vanilladot} Linear kernel function
      \item \code{tanhdot} Hyperbolic tangent kernel function
      \item \code{laplacedot} Laplacian kernel function
      \item \code{besseldot} Bessel kernel function
      \item \code{anovadot} ANOVA RBF kernel function
    }
    The kernel parameter can also be set to a user defined function of
    class kernel by passing the function name as an argument.
  }

  \item{kpar}{the list of hyper-parameters (kernel parameters).
    This is a list which contains the parameters to be used with the
    kernel function. For valid parameters for existing kernels are :
    \itemize{
      \item \code{sigma} inverse kernel width for the Radial Basis
      kernel function "rbfdot" and the Laplacian kernel "laplacedot".
      \item \code{degree, scale, offset} for the Polynomial kernel "polydot"
      \item \code{scale, offset} for the Hyperbolic tangent kernel
      function "tanhdot"
      \item \code{sigma, order, degree} for the Bessel kernel "besseldot". 
      \item \code{sigma, degree} for the ANOVA kernel "anovadot".
    }
   
    Hyper-parameters for user defined kernels can be passed through the
    kpar parameter as well.}

  \item{var}{the initial noise variance}

  \item{tol}{tolerance of termination criterion (default: 0.001)}

  \item{fit}{indicates whether the fitted values should be computed and
          included in the model or not (default: 'TRUE')}
	\item{cross}{if a integer value k>0 is specified, a k-fold cross
          validation on the training data is performed to assess the
          quality of the model: the Mean Squared Error for regression}

	\item{subset}{An index vector specifying the cases to be used in the
          training sample.  (NOTE: If given, this argument must be
          named.)}
  \item{na.action}{A function to specify the action to be taken if \code{NA}s are
          found. The default action is \code{na.omit}, which leads to rejection of cases
          with missing values on any required variable. An alternative
	  is \code{na.fail}, which causes an error if \code{NA} cases
	  are found. (NOTE: If given, this argument must be named.)}
	

  \item{\dots}{ additional parameters}

}
\details{
 A Gaussian process is specified by a mean and a covariance function.
  The mean is a function of x (which is often the zero function), and
  the covariance
is a function C(x,x) which expresses the expected covariance between the
value of the function y at the points x and x.
The actual function y(x) in any data modelling problem is assumed to be
a single sample from this Gaussian distribution.

}
\value{
An S4 object of class "gausspr" containing the fitted model along with
information.
 Accessor functions can be used to access the slots of the
  object which include :
  \item{alpha}{The resulting model parameters}
  \item{error}{Training error (if fit == TRUE)}
  
  }
  \references{
    Christopher K.I. Williams, Carl Edward Rasmussen
    \emph{Gaussian Processes for Regression}
    Advances in Neural Information Processing Systems, NIPS
    \url{http://books.nips.cc/papers/files/nips08/0514.pdf}

  }
\author{Alexandros Karatzoglou \cr \email{alexandros.karatzoglou@ci.tuwien.ac.at}}


\seealso{\code{\link{rvm}}, \code{\link{ksvm}} }

\examples{
# train model
data(iris)
test <- gausspr(Species~.,data=iris,var=2)
test
alpha(test)

# predict on the training set
predict(test,iris[,-5])


# create regression data
x <- seq(-20,20,0.1)
y <- sin(x)/x + rnorm(401,sd=0.03)

# regression with gaussian processes
foo <- gausspr(x, y)
foo

# predict and plot
ytest <- predict(foo, x)
plot(x, y, type ="l")
lines(x, ytest, col="red")
}
\keyword{classif}
\keyword{regression}
\keyword{nonlinear}

\eof
\name{inc.chol-class}
\docType{class}
\alias{inc.chol-class}
\alias{diag.residues}
\alias{maxresiduals}
\alias{pivots}
\alias{diag.residues,inc.chol-method}
\alias{maxresiduals,inc.chol-method}
\alias{pivots,inc.chol-method}

\title{Class "inc.chol" }
\description{  The reduced Cholesky decomposition object}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("inc.chol", ...)}.
  or by calling the  \code{chol.reduce} function.
}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{Object of class \code{"matrix"} contains the decomposed matrix}
    \item{\code{pivots}:}{Object of class \code{"vector"} contains the
      pivots performed}
    \item{\code{diag.residues}:}{Object of class \code{"vector"}
      contains the diagonial residues}
    \item{\code{maxresiduals}:}{Object of class \code{"vector"} contains
    the maximum residues}
  }
}
\section{Extends}{
Class \code{"matrix"}, directly.
}
\section{Methods}{
  \describe{
    \item{diag.residues}{\code{signature(object = "inc.chol")}: returns
      the diagonial residues }
    \item{maxresiduals}{\code{signature(object = "inc.chol")}: returns
      the maximum residues }
    \item{pivots}{\code{signature(object = "inc.chol")}: returns the
      pivots performed }
  }
}

\author{Alexandros Karatzoglou\cr \email{alexandros.karatzoglou@ci.tuwien.ac.at}}


\seealso{
 \code{\link{chol.reduce}}
  }
\examples{
data(iris)
datamatrix <- as.matrix(iris[,-5])
# initialize kernel function
rbf <- rbfdot(sigma=0.1)
rbf
Z <- chol.reduce(datamatrix,kernel=rbf)
dim(Z)
pivots(Z)
diag.residues(Z)
maxresiduals(Z)
}
\keyword{classes}

\eof
\name{income}
\alias{income}
\title{Income Data}
\description{
Customer Income Data from a marketing survey.
}
\usage{data(income)}

\format{
  A data frame with 14 categorical variables (8993 observations).

  Explanation of the variable names:

  \tabular{rllll}{
    \tab 1 \tab \code{INCOME} \tab annual income of household \tab \cr
    \tab   \tab               \tab (Personal income if single) \tab ordinal\cr
    \tab 2 \tab \code{SEX} \tab sex \tab nominal\cr
    \tab 3 \tab \code{MARITAL.STATUS} \tab marital status \tab nominal\cr
    \tab 4 \tab \code{AGE} \tab age \tab ordinal\cr
    \tab 5 \tab \code{EDUCATION} \tab educational grade \tab ordinal\cr
    \tab 6 \tab \code{OCCUPATION} \tab type of work \tab nominal \cr
    \tab 7 \tab \code{AREA} \tab how long the interviewed person has lived\tab
    \cr
    \tab   \tab             \tab in the San Francisco/Oakland/San Jose area \tab ordinal\cr
    \tab 8 \tab \code{DUAL.INCOMES} \tab dual incomes (if married) \tab nominal\cr
    \tab 9 \tab \code{HOUSEHOLD.SIZE} \tab persons living in the
    household \tab ordinal\cr
    \tab 10 \tab \code{UNDER18} \tab persons in household under 18 \tab ordinal\cr
    \tab 11 \tab \code{HOUSEHOLDER} \tab householder status \tab nominal\cr
    \tab 12 \tab \code{HOME.TYPE} \tab type of home \tab nominal\cr
    \tab 13 \tab \code{ETHNIC.CLASS} \tab ethnic classification \tab nominal\cr
    \tab 14 \tab \code{LANGUAGE} \tab language most often spoken at
    home \tab nominal\cr
  }
}
\details{
A total of N=9409 questionnaires containg 502 questions were 
filled out by shopping mall customers in the San Francisco Bay area. 
The dataset is an extract from this survey. It consists of 
14 demographic attributes. The dataset is a mixture of nominal and
ordinal variables with a lot of missing data.
The goal is to predict the Anual Income of Household from the other 13
demographics attributes.
}
\source{
  Impact Resources, Inc., Columbus, OH (1987).
}
}
\keyword{datasets}

\eof
\name{ipop-class}
\docType{class}
\alias{ipop-class}
\alias{primal,ipop-method}
\alias{dual,ipop-method}
\alias{how,ipop-method}
\alias{primal}
\alias{dual}
\alias{how}

\title{Class "ipop"}
\description{The quadratic problem solver class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("ipop", ...)}.
   or by calling the \code{ipop} function.
}
\section{Slots}{
  \describe{
    \item{\code{primal}:}{Object of class \code{"vector"} the primal
      solution of the problem}
    \item{\code{dual}:}{Object of class \code{"numeric"} the dual of the
    problem}
    \item{\code{how}:}{Object of class \code{"character"} convergence information}
  }
}
\section{Methods}{
  \item{\code{primal}}{Return the primal of the problem}
  \item{\code{dual}}{Return the dual of the problem}
  \item{\code{how}}{Return information on convergence}
  }

  \author{Alexandros Karatzoglou\cr
    \email{alexandros.karatzoglou@ci.tuwien.ac.at}}

\seealso{
  \code{\link{ipop}}

}
\examples{
## solve the Support Vector Machine optimization problem
data(spam)

## sample a scaled part (300 points) of the spam data set
m <- 300
set <- sample(1:dim(spam)[1],m)
x <- scale(as.matrix(spam[,-58]))[set,]
y <- as.integer(spam[set,58])
y[y==2] <- -1

##set C parameter and kernel
C <- 5
rbf <- rbfdot(sigma = 0.1)

## create H matrix etc.
H <- kernelPol(rbf,x,,y)
c <- matrix(rep(-1,m))
A <- t(y)
b <- 0
l <- matrix(rep(0,m))
u <- matrix(rep(C,m))
r <- 0

sv <- ipop(c,H,A,b,l,u,r)
primal(sv)
dual(sv)
how(sv)

}
\keyword{classes}

\eof
\name{ipop}
\alias{ipop}
\alias{ipop,ANY,matrix-method}

\title{Quadratic Programming Solver}
\description{
  ipop solves the quadratic programming problem :\cr
  \eqn{\min(c'*x + 1/2 * x' * H * x)}\cr
  subject to: \cr
  \eqn{b <= A * x <= b + r}\cr
  \eqn{l <= x <= u}
}
\usage{
ipop(c, H, A, b, l, u, r, sigf = 7, maxiter = 40, margin = 0.05, bound = 10, verb = 0)
}

\arguments{
  \item{c}{Vector or one column matrix appearing in the quadratic function}
  \item{H}{Matrix appearing in the quadratic function}
  \item{A}{Matrix defining the constrains under which we minimize the
    quadratic function}
  \item{b}{Vector or one column matrix defining the constrains}
  \item{l}{Lower bound vector or one column matrix}
  \item{u}{Upper bound vector or one column matrix}
  \item{r}{Vector or one column matrix defining constrains}
  \item{sigf}{Precision (default: 7 significant figures)}
  \item{maxiter}{Maximum number of iterations}
  \item{margin}{how close we get to the constrains}
  \item{bound}{Clipping bound for the variables}
  \item{verb}{Display convergence information during runtime}
}
\details{
ipop uses an interior point method to solve the quadratic programming problem.
}
\value{
  An S4 object with the following slots
  \item{primal}{Vector containing the primal solution of the quadratic problem}
  \item{dual}{The dual solution of the problem}
  \item{how}{Character string describing the type of convergence}

  all slots can be accessed through accessor functions (see example)
}
\references{
  R. J. Vanderbei\cr
  \emph{LOQO: An interior point code for quadratic programming}\cr
  Optimization Methods and Software 11, 451-484, 1999 \cr
  \url{http://www.sor.princeton.edu/~rvdb/ps/loqo3.ps.gz}
}
\author{Alexandros Karatzoglou (based on Matlab code by Alex Smola) \cr
alexandros.karatzoglou@ci.tuwien.ac.at}


\seealso{\code{solve.QP}}
\examples{
## solve the Support Vector Machine optimization problem
data(spam)

## sample a scaled part (500 points) of the spam data set
m <- 500
set <- sample(1:dim(spam)[1],m)
x <- scale(as.matrix(spam[,-58]))[set,]
y <- as.integer(spam[set,58])
y[y==2] <- -1

##set C parameter and kernel
C <- 5
rbf <- rbfdot(sigma = 0.1)

## create H matrix etc.
H <- kernelPol(rbf,x,,y)
c <- matrix(rep(-1,m))
A <- t(y)
b <- 0
l <- matrix(rep(0,m))
u <- matrix(rep(C,m))
r <- 0

sv <- ipop(c,H,A,b,l,u,r)
sv
dual(sv)

}
\keyword{optimize}


\eof
\name{kcca-class}
\docType{class}
\alias{kcca-class}
\alias{kcor}
\alias{xcoef}
\alias{ycoef}
\alias{yvar}
\alias{xvar}
\alias{kcor,kcca-method}
\alias{xcoef,kcca-method}
\alias{xvar,kcca-method}
\alias{ycoef,kcca-method}
\alias{yvar,kcca-method}

\title{Class "kcca"}
\description{The "kcca" class  }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("kcca", ...)}.
    or by the calling the \code{kcca} function. 
}
\section{Slots}{
  \describe{
    \item{\code{kcor}:}{Object of class \code{"vector"} describing the correlations}
    \item{\code{xcoef}:}{Object of class \code{"matrix"} estimated coefficients for the \code{x} variables}
    \item{\code{ycoef}:}{Object of class \code{"matrix"} estimated coefficients for the \code{y} variables }
    \item{\code{xvar}:}{Object of class \code{"matrix"} holds the
      canonical variates for \code{x}}
    \item{\code{yvar}:}{Object of class \code{"matrix"} holds the
      canonical variates for \code{y}}
  }
}
\section{Methods}{
  \describe{
    \item{kcor}{\code{signature(object = "kcca")}: returns the correlations}
    \item{xcoef}{\code{signature(object = "kcca")}: returns the estimated coefficients for the \code{x} variables}
    \item{ycoef}{\code{signature(object = "kcca")}: returns the estimated coefficients for the \code{y} variables }
    \item{xvar}{\code{signature(object = "kcca")}: returns the canonical
    variates for \code{x}}
    \item{yvar}{\code{signature(object = "kcca")}: returns the canonical
    variates for \code{y}}
  }
}

\author{Alexandros Karatzoglou \cr
\email{alexandros.karatzoglou@ci.tuwien.ac.at}}


\seealso{
  \code{\link{kcca}},
  \code{\link{kpca-class}} 
}
\examples{

}
\keyword{classes}

\eof
\name{kcca}
\alias{kcca}
\alias{kcca,matrix-method}
\title{Kernel Canonical Correlation Analysis}
\description{
Computes the canonical correlation analysis in a feature space.
}
\usage{
\S4method{kcca}{matrix}(x, y, kernel="rbfdot", kpar=list(sigma=0.1), ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{a matrix containing data index by row}
  \item{y}{a matrix containing data index by row}
  \item{kernel}{the kernel function used in training and predicting.
    This parameter can be set to any function, of class kernel, which computes a dot product between two
    vector arguments. kernlab provides the most popular kernel functions
    which can be used by setting the kernel parameter to the following
    strings:
    \itemize{
      \item \code{rbfdot} Radial Basis kernel function "Gaussian"
      \item \code{polydot} Polynomial kernel function
      \item \code{vanilladot} Linear kernel function
      \item \code{tanhdot} Hyperbolic tangent kernel function
      \item \code{laplacedot} Laplacian kernel function
      \item \code{besseldot} Bessel kernel function
      \item \code{anovadot} ANOVA RBF kernel function
    }
    The kernel parameter can also be set to a user defined function of
    class kernel by passing the function name as an argument.
  }

  \item{kpar}{the list of hyper-parameters (kernel parameters).
    This is a list which contains the parameters to be used with the
    kernel function. For valid parameters for existing kernels are :
    \itemize{
      \item \code{sigma} inverse kernel width for the Radial Basis
      kernel function "rbfdot" and the Laplacian kernel "laplacedot".
      \item \code{degree, scale, offset} for the Polynomial kernel "polydot"
      \item \code{scale, offset} for the Hyperbolic tangent kernel
      function "tanhdot"
      \item \code{sigma, order, degree} for the Bessel kernel "besseldot". 
      \item \code{sigma, degree} for the ANOVA kernel "anovadot".
    }
 
    Hyper-parameters for user defined kernels can be passed through the
    kpar parameter as well.}

  \item{\dots}{adittional parameters for the \code{kpca} function}
}
\details{
The kernel version of the classical canonical correlation analysis. 
}
\value{
  An S4 object containg the following slots:
  \item{kcor}{Correlation coefficients in feature space}
  \item{xcoef}{estimated coefficients for the \code{x} variables in the
    feature space}
  \item{ycoef}{estimated coefficients for the \code{y} variables in the
    feature space}
  \item{xvar}{The canonical variates for \code{x}}
  \item{yvar}{The canonical variates for \code{y}}
    
}
\references{ ~put references to the literature/web site here ~ }
\author{ Alexandros Karatzoglou \cr \email{alexandros.karatzoglou@ci.tuwien.ac.at}}


\seealso{\code{cancor}  \code{kpca}}
\examples{

}
\keyword{multivariate}


\eof
\name{kernel-class}
\docType{class}
\alias{rbfkernel-class}
\alias{polykernel-class}
\alias{vanillakernel-class}
\alias{tanhkernel-class}
\alias{anovakernel-class}
\alias{besselkernel-class}
\alias{laplacekernel-class}
\alias{kernel-class}
\alias{kpar,kernel-method}
\title{Class "kernel" "rbfkernel" "polykernel", "tanhkernel", "vanillakernel"}
\description{  The build in \code{kernel} classes in \code{kernelab}}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("rbfkernel", ...)},
\code{new{"polykernel"}}, \code{new{"tanhkernel"}},
\code{new{"vanillakernel"}}
or by calling the \code{rbfdot}, \code{polydot}, \code{tanhdot},
\code{vanilladot} functions.
}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{Object of class \code{"function"} containing
      the kernel function }
    \item{\code{kpar}:}{Object of class \code{"list"} containing the
      kernel parameters }
  }
}
\section{Extends}{
Class \code{"kernel"}, directly.
Class \code{"function"}, by class \code{"kernel"}.
}
\section{Methods}{
  \describe{
    \item{kernelMatrix}{\code{signature(kernel = "rbfkernel", x =
	"matrix")}: computes the kernel matrix }
    \item{kernelMult}{\code{signature(kernel = "rbfkernel", x =
	"matrix")}: computes the quadratic kernel expression}
    \item{kernelPol}{\code{signature(kernel = "rbfkernel", x =
	"matrix")}: computes the kernel expansion }
  }
}

\author{Alexandros Karatzoglou\cr \email{alexandros.karatzoglou@ci.tuwien.ac.at} }



\seealso{
  \code{\link{dots}}
  
}
\examples{

rbfkernel <- rbfdot(sigma = 0.1)
rbfkernel
is(rbfkernel)
kpar(rbfkernel)

}
\keyword{classes}

\eof
\name{kernelMatrix}
\alias{kernelMatrix}
\alias{kernelMult}
\alias{kernelPol}
\alias{kernelPol,kernel-method}
\alias{kernelMatrix,kernel-method}
\alias{kernelMult,kernel-method}
\alias{kernelMatrix,rbfkernel,matrix-method}
\alias{kernelMatrix,polykernel,matrix-method}
\alias{kernelMatrix,vanillakernel,matrix-method}
\alias{kernelMatrix,tanhkernel,matrix-method}
\alias{kernelMatrix,laplacekernel,matrix-method}
\alias{kernelMatrix,anovakernel,matrix-method}
\alias{kernelMatrix,besselkernel,matrix-method}
\alias{kernelMult,rbfkernel,matrix-method}
\alias{kernelMult,polykernel,matrix-method}
\alias{kernelMult,tanhkernel,matrix-method}
\alias{kernelMult,laplacekernel,matrix-method}
\alias{kernelMult,besselkernel,matrix-method}
\alias{kernelMult,anovakernel,matrix-method}
\alias{kernelMult,vanillakernel,matrix-method}
\alias{kernelPol,rbfkernel,matrix-method}
\alias{kernelPol,polykernel,matrix-method}
\alias{kernelPol,tanhkernel,matrix-method}
\alias{kernelPol,vanillakernel,matrix-method}
\alias{kernelPol,anovakernel,matrix-method}
\alias{kernelPol,besselkernel,matrix-method}
\alias{kernelPol,laplacekernel,matrix-method}


\title{Kernel Matrix functions}
\description{
  \code{kernelMatrix} calculates the kernel matrix \eqn{K_{ij} = k(x_i,x_j)} or \eqn{K_{ij} =
    k(x_i,y_j)}.\cr
  \code{kernelPol} computes the quadratic kernel expression  \eqn{H = z_i z_j
    k(x_i,x_j)}, \eqn{H = z_i k_j k(x_i,y_j)}.\cr
    \code{kernelMult} calculates the kernel expansion \eqn{f(x_i) =
      sum_{i=1}^m z k(x_i,x_j)} 
 }
\usage{
\S4method{kernelMatrix}{kernel}(kernel, x, y = NULL)

\S4method{kernelPol}{kernel}(kernel, x, y = NULL, z, k = NULL)

\S4method{kernelMult}{kernel}(kernel, x, y = NULL, z, blocksize = 256)
}

\arguments{
  \item{kernel}{the kernel function to be used to calculate the kernel
    matrix.
  This has to be a function of class \code{kernel}}
  \item{x}{a data matrix to be used to calculate the kernel matrix}
  \item{y}{second data matrix to calculate the kernel matrix}
  \item{z}{a suitable vector or matrix}
  \item{k}{a suitable vector or matrix}
  \item{blocksize}{the kernel expansion computations are done block wise
    to avoid storing the kernel matrix into memory. \code{blocksize}
    defines the size of the computational blocks.}
}
\details{
  Common functions used during kernel based computations.\cr
  This \code{kernel} parameter can be set to any function, of class
  kernel, which computes a dot product between two
  vector arguments. kernlab provides the most popular kernel functions
  which can be initialized by using the following
  functions:
    \itemize{
      \item \code{rbfdot} Radial Basis kernel function
      \item \code{polydot} Polynomial kernel function
      \item \code{vanilladot} Linear kernel function
      \item \code{tanhdot} Hyperbolic tangent kernel function
      \item \code{laplacedot} Laplacian kernel function
      \item \code{besseldot} Bessel kernel function
      \item \code{anovadot} ANOVA RBF kernel function
    }  (see example.)
  }
  
\value{
  \code{kernelMatrix} returns a symmetric diagonal semi-definite matrix.
  \code{kernelPol} returns a matrix.
  \code{kernelMult}{usually returns a one-column matrix}
}
\author{Alexandros Karatzoglou \cr
\email{alexandros.karatzoglou@ci.tuwien.ac.at}}


\seealso{\code{\link{rbfdot}}, \code{\link{polydot}},
  \code{\link{tanhdot}}, \code{\link{vanilladot}}}

\examples{
## use the spam data
data(spam)
dt <- as.matrix(spam[c(10:20,3000:3010),-58])

## initialize kernel function 
rbf <- rbfdot(sigma = 0.05)
rbf

## calculate kernel matrix
kernelMatrix(rbf, dt)

yt <- as.matrix(as.integer(spam[c(10:20,3000:3010),58]))
yt[yt==2] <- -1

## calculate the quadratic kernel expression
kernelPol(rbf, dt, ,yt)

## calculate the kernel expansion
kernelMult(rbf, dt, ,yt)
}
\keyword{algebra}
\keyword{array}

\eof
\name{kpca-class}
\docType{class}
\alias{kpca-class}
\alias{eig}
\alias{pcv}
\alias{rotated}
\alias{eig,kpca-method}
\alias{kcall,kpca-method}
\alias{kernelf,kpca-method}
\alias{pcv,kpca-method}
\alias{rotated,kpca-method}
\alias{xmatrix,kpca-method}

\title{Class "kpca"}
\description{ The Kernel Principal Components Analysis class}
\section{Objects objects of class "kpca"}{
Objects can be created by calls of the form \code{new("kpca", ...)}.
    or by calling the \code{kpca} function.
}
\section{Slots}{
  \describe{
    \item{\code{pcv}:}{Object of class \code{"matrix"} containing the
      principal component vectors }
    \item{\code{eig}:}{Object of class \code{"vector"} containing the
      coresponding eigenvalues}
    \item{\code{rotated}:}{Object of class \code{"matrix"} containing the
      projection of the data on the principal components}
    \item{\code{kernelf}:}{Object of class \code{"function"} containing
      the kernel function used}
    \item{\code{kpar}:}{Object of class \code{"list"} containing the
      kernel parameters used }
    \item{\code{xmatrix}:}{Object of class \code{"matrix"} conatining
      the data matrix used }
    \item{\code{kcall}:}{Object of class \code{"ANY"} containing the
      function call }
    \item{\code{n.action}:}{Object of class \code{"ANY"} containg the
      action performed on NA }
  }
}
\section{Methods}{
  \describe{

    \item{eig}{\code{signature(object = "kpca")}: returns the eigenvalues }

    \item{kcall}{\code{signature(object = "kpca")}: returns the
      performed call}
    \item{kernelf}{\code{signature(object = "kpca")}: returns the used
      kernel function}
    \item{pcv}{\code{signature(object = "kpca")}: returns the principal
      component vectors }
    \item{predict}{\code{signature(object = "kpca")}: embeeds new data }
    \item{rotated}{\code{signature(object = "kpca")}: returns the
      projected data}
    \item{xmatrix}{\code{signature(object = "kpca")}: returns the used
      data matrix }
  }
}

\author{Alexandros Karatzoglou\cr \email{alexandros.karatzoglou@ci.tuwien.ac.at}}

\seealso{
  \code{\link{ksvm-class}}, 
   \code{\link{kcca-class}} 
}
\examples{
# another example using the iris
data(iris)
test <- sample(1:50,20)

kpc <- kpca(~.,data=iris[-test,-5],kernel="rbfdot",kpar=list(sigma=0.2),features=2)

#print the principal component vectors
pcv(kpc)
rotated(kpc)
kernelf(kpc)
eig(kpc)
}
\keyword{classes}

\eof
\name{kpca}
\alias{kpca}
\alias{kpca,formula-method}
\alias{kpca,matrix-method}
\alias{predict,kpca-method}
\title{Kernel Principal Components Analysis}
\description{
Kernel Principal Components Analysis is a nonlinear form of principal
component analysis.}
\usage{
\S4method{kpca}{formula}(x, data = NULL, na.action, ...)

\S4method{kpca}{matrix}(x, kernel = "rbfdot", kpar = list(sigma = 0.1), features = 0, th = 1e-4, ...)
}

\arguments{
  \item{x}{ The data matrix indexed by row
    or a formula descibing the model. Note, that an
          intercept is always included, whether given in the formula or
          not.} 
	\item{data}{an optional data frame containing the variables in
	  the model
	  (when using a formula).}
	
	\item{kernel}{the kernel function used in training and predicting.
    This parameter can be set to any function, of class kernel, which computes a dot product between two
    vector arguments. kernlab provides the most popular kernel functions
    which can be used by setting the kernel parameter to the following
    strings:
    \itemize{
      \item \code{rbfdot} Radial Basis kernel function "Gaussian"
      \item \code{polydot} Polynomial kernel function
      \item \code{vanilladot} Linear kernel function
      \item \code{tanhdot} Hyperbolic tangent kernel function
      \item \code{laplacedot} Laplacian kernel function
      \item \code{besseldot} Bessel kernel function
      \item \code{anovadot} ANOVA RBF kernel function
    }
    The kernel parameter can also be set to a user defined function of
    class kernel by passing the function name as an argument.
  }

  \item{kpar}{the list of hyper-parameters (kernel parameters).
    This is a list which contains the parameters to be used with the
    kernel function. For valid parameters for existing kernels are :
    \itemize{
      \item \code{sigma} inverse kernel width for the Radial Basis
      kernel function "rbfdot" and the Laplacian kernel "laplacedot".
      \item \code{degree, scale, offset} for the Polynomial kernel "polydot"
      \item \code{scale, offset} for the Hyperbolic tangent kernel
      function "tanhdot"
      \item \code{sigma, order, degree} for the Bessel kernel "besseldot". 
      \item \code{sigma, degree} for the ANOVA kernel "anovadot".
    }
    Hyper-parameters for user defined kernels can be passed through the
    kpar parameter as well.}
  
  \item{features}{Number of features (principal components) to
    return. (default: 0 , all)}

    \item{th}{the value of the eigenvalue under which principal
      components are ignored (only valid when features =  0). (default : 0.0001) }

  \item{na.action}{A function to specify the action to be taken if \code{NA}s are
          found. The default action is \code{na.omit}, which leads to rejection of cases
          with missing values on any required variable. An alternative
	  is \code{na.fail}, which causes an error if \code{NA} cases
	  are found. (NOTE: If given, this argument must be named.)}
    
  \item{\dots}{ additional parameters}

}
\details{By the use of kernel functions one can efficiently compute
  principal components in high-dimensional 
 feature spaces, related to input space by some non-linear map.
}
\value{
 An S4 object containing the principal component vectors along with the
 corresponding eigenvalues. 
  \item{pcv}{a matrix containing the principal component vectors (column
  wise)}
\item{eig}{The corresponding eigenvalues}
\item{rotated}{The original data projected (rotated) on the principal components}
\item{xmatrix}{The original data matrix}

all the slots of the object can be accessed by accessor functions.
}
\notes{The predict function can be used to embed new data on the new space}
\references{
  Schoelkopf B., A. Smola, K.-R. Mueller :\cr
  \emph{Nonlinear component analysis as a kernel eigenvalue problem}\cr
  Neural Computation 10, 1299-1319\cr
  \url{http://mlg.anu.edu.au/~smola/papers/SchSmoMul98.pdf}
}
\author{Alexandros Karatzoglou \cr
\email{alexandros.karatzoglou@ci.tuwien.ac.at}}


\seealso{\code{\link{kcca}}, \code{pca}}
\examples{
# another example using the iris
data(iris)
test <- sample(1:50,20)

kpc <- kpca(~.,data=iris[-test,-5],kernel="rbfdot",kpar=list(sigma=0.2),features=2)

#print the principal component vectors
pcv(kpc)

#plot the data projection on the components
plot(rotated(kpc),col=as.integer(iris[-test,5]),xlab="1st Principal Component",ylab="2nd Principal Component")

#embed remaining points 
emb <- predict(kpc,as.matrix(iris[test,-5]))
points(emb,col=iris[test,5])
}
\keyword{cluster}


\eof
\name{ksvm-class}
\docType{class}
\alias{ksvm-class}
\alias{SVindex}
\alias{cross}
\alias{alpha}
\alias{alphaindex}
\alias{coeff}
\alias{cross}
\alias{error}
\alias{fit}
\alias{prob.model}
\alias{type}
\alias{kernelf}
\alias{xmatrix}
\alias{ymatrix}
\alias{scaling}
\alias{lev}
\alias{kcall}
\alias{prior}
\alias{show}
\alias{SVindex,ksvm-method}
\alias{alpha,ksvm-method}
\alias{alphaindex,ksvm-method}
\alias{cross,ksvm-method}
\alias{error,ksvm-method}
\alias{fit,ksvm-method}
\alias{prior,ksvm-method}
\alias{prob.model,ksvm-method}
\alias{kernelf,ksvm-method}
\alias{kpar,ksvm-method}
\alias{lev,ksvm-method}
\alias{kcall,ksvm-method}
\alias{scaling,ksvm-method}
\alias{type,ksvm-method}
\alias{xmatrix,ksvm-method}
\alias{ymatrix,ksvm-method}



\title{Class "ksvm" }
\description{An S4 class containing the output (model) of the
  \code{ksvm} Support Vector Machines function }
\section{Objects from the Class}{
  Objects can be created by calls of the form \code{new("ksvm", ...)}
  or by calls to the \code{ksvm} function.

}
\section{Slots}{
  \describe{
    \item{\code{type}:}{Object of class \code{"character"}  containing
      the problem support vector machine problem type
      ("C-classification", "nu-classification", "spoc-classification",
      "one-classification", "eps-regression", "nu-regression")}
    \item{\code{param}:}{Object of class \code{"list"} containing the
      Support Vector Machine parameters (C, nu, epsilon)}
    \item{\code{kernelf}:}{Object of class \code{"function"} containing
      the kernel function}
    \item{\code{kpar}:}{Object of class \code{"list"} containing the
      kernel function parameters (hyperparameters)}
    \item{\code{kcall}:}{Object of class \code{"ANY"} containing the      \code{ksvm} function call}
    \item{\code{scaling}:}{Object of class \code{"ANY"} containing the
      scaling information performed on the data}
    \item{\code{kterms}:}{Object of class \code{"ANY"} containing the
      terms representation of the symbolic model used (when using a formula)}
    \item{\code{xmatrix}:}{Object of class \code{"matrix"} the data
      matrix used during computations (possibly scaled and whithout NA)}
    \item{\code{ymatrix}:}{Object of class \code{"ANY"} the response matrix/vector }
    \item{\code{fit}:}{Object of class \code{"ANY"} with the fitted values,
      predictions using the training set.}
    \item{\code{lev}:}{Object of class \code{"vector"} with the levels of the
      response (in the case of classifiaction)}
    \item{\code{prob.model}:}{Object of class \code{"list"} with the
      class prob. model}
    \item{\code{prior}:}{Object of class \code{"list"} with the
      prior of the training set}
    \item{\code{nclass}:}{Object of class \code{"numeric"}  containing
      the number of classes (in the case of classification)}
    \item{\code{alpha}:}{Object of class \code{"ANY"} containing the
      resulting alpha vector (list or matrix in case of multiclass classification) (support vectors)}
    \item{\code{coeff}:}{Object of class \code{"ANY"} containing the
      resulting coefficients}
    \item{\code{alphaindex}:}{Object of class \code{"list"} containing}
    \item{\code{b}:}{Object of class \code{"numeric"} containing the
      resulting offset }
    \item{\code{SVindex}:}{Object of class \code{"vector"} containing
      the indexes of the support vectors}
    \item{\code{nSV}:}{Object of class \code{"numeric"} containing the
      number of suppport vector machines }
    \item{\code{error}:}{Object of class \code{"numeric"} containing the
    training error}
    \item{\code{cross}:}{Object of class \code{"numeric"} containing the
      cross-validation error }
    \item{\code{n.action}:}{Object of class \code{"ANY"} containing the
      action performed for NA }
  }
}
\section{Methods}{
  \describe{
    \item{SVindex}{\code{signature(object = "ksvm")}: return the indexes
    of support vectors}
    \item{alpha}{\code{signature(object = "ksvm")}: returns the complete
    alpha vector (wit zero values)}
    \item{alphaindex}{\code{signature(object = "ksvm")}: returns the
      indexes of non-zero alphas (support vectors)}
    \item{cross}{\code{signature(object = "ksvm")}: returns the
      cross-validation error }
    \item{error}{\code{signature(object = "ksvm")}: returns the training
      error }
    \item{fit}{\code{signature(object = "ksvm")}: returns the fitted
      values (predict on training set) }
    \item{kernelf}{\code{signature(object = "ksvm")}: returns the kernel
    function}
    \item{kpar}{\code{signature(object = "ksvm")}: returns the kernel
      parameters (hyperparameters)}
    \item{lev}{\code{signature(object = "ksvm")}: returns the levels in
      case of classification  }
    \item{prob.model}{\code{signature(object="ksvm")}: returns class
      prob. model values}
    \item{prior}{\code{signature(object="ksvm")}: returns 
      the prior of the training set}
    \item{kcall}{\code{signature(object="ksvm")}: returns the
    \code{ksvm} function call}
    \item{scaling}{\code{signature(object = "ksvm")}: returns the
      scaling values }
    \item{show}{\code{signature(object = "ksvm")}: prints the object information}
    \item{type}{\code{signature(object = "ksvm")}: returns the problem type}
    \item{xmatrix}{\code{signature(object = "ksvm")}: returns the data
      matrix used}
    \item{ymatrix}{\code{signature(object = "ksvm")}: returns the
      response vector}
  }
}

\author{Alexandros Karatzoglou \cr \email{alexandros.karatzolgou@ci.tuwien.ac.at}}


\seealso{
  \code{\link{ksvm}}, 
  \code{\link{rvm-class}},
  \code{\link{gausspr-class}}
}
\examples{
## simple example using the spam data set
data(spam)

## create test and training set
spamtrain <- spam[1:(2 * dim(spam)[1]/3), ]
spamtest <- spam[((2 * dim(spam)[1]/3) + 1):length(spam), ]

## train a support vector machine
filter <- ksvm(type~.,data=spamtrain,kernel="rbfdot",kpar=list(sigma=0.05),C=5,cross=3)
filter

# the kernel  function
kernelf(filter)
# the alpha values
alpha(filter)
# the coefficients
coeff(filter)
# the fitted values
fit(filter)
# the cross validation error
cross(filter)


}
\keyword{classes}

\eof
\name{ksvm}
\alias{ksvm}
\alias{ksvm,formula-method}
\alias{ksvm,vector-method}
\alias{ksvm,matrix-method}
\alias{show,ksvm-method}
\alias{coeff,ksvm-method}
\title{Support Vector Machines}
\description{
  Support Vector Machines are an excellent tool
  for classification as well as regression. \code{ksvm} supports the
  classical C-classification, nu-classification, one-class-classification
  e-regression, nu-regression along with the Crammer-Singer method
  for multi-class classification spoc-classification.\cr
  A probabilistic prediction function for classification is also included.
}
\usage{
\S4method{ksvm}{formula}(x, data = NULL, ..., subset, na.action = na.omit, scaled = TRUE)

\S4method{ksvm}{vector}{x, ...}

\S4method{ksvm}{matrix}(x, y = NULL, scaled = TRUE, type = NULL, kernel ="rbfdot", kpar = list(sigma = 0.1),
C = 1, nu = 0.2, epsilon = 0.1, prob.model = FALSE, class.weights = NULL, cachesize = 40, tol = 0.001,
shrinking = TRUE, cross = 0, fit = TRUE, ..., subset, na.action = na.omit)
}

\arguments{
  \item{x}{a symbolic description of the model to be fit. Note, that an
          intercept is always included, whether given in the formula or
          not. When not using a formula x is a matrix or vector
	  containg the variables in the model}
  \item{data}{an optional data frame containing the variables in the model.
          By default the variables are taken from the environment which
          `ksvm' is called from.}
	  
  \item{y}{a response vector with one label for each row/component of \code{x}. Can be either
    a factor (for classification tasks) or a numeric vector (for
    regression).}
  \item{scaled}{A logical vector indicating the variables to be
    scaled. If \code{scaled} is of length 1, the value is recycled as
    many times as needed and all non-binary variables are scaled.
    Per default, data are scaled internally (both \code{x} and \code{y}
    variables) to zero mean and unit variance. The center and scale
    values are returned and used for later predictions.}
  \item{type}{\code{ksvm} can be used for classification
    , for regression, or for novelty detection.
    Depending on whether \code{y} is
    a factor or not, the default setting for \code{type} is \code{C-classification} or \code{eps-regression}, respectively, but can be overwritten by setting an explicit value.\cr
    Valid options are:
    \itemize{
      \item \code{C-classification}
      \item \code{nu-classification}
      \item \code{spoc-classification} (Crammer Singer multi-class)
      \item \code{one-classification} (novelty detection)
      \item \code{eps-regression}
      \item \code{nu-regression}
    }
  }
  \item{kernel}{the kernel function used in training and predicting.
    This parameter can be set to any function, of class kernel, which computes a dot product between two
    vector arguments. kernlab provides the most popular kernel functions
    which can be used by setting the kernel parameter to the following
    strings:
    \itemize{
      \item \code{rbfdot} Radial Basis kernel function "Gaussian"
      \item \code{polydot} Polynomial kernel function
      \item \code{vanilladot} Linear kernel function
      \item \code{tanhdot} Hyperbolic tangent kernel function
      \item \code{laplacedot} Laplacian kernel function
      \item \code{besseldot} Bessel kernel function
      \item \code{anovadot} ANOVA RBF kernel function
    }
    The kernel parameter can also be set to a user defined function of
    class kernel by passing the function name as an argument.
  }

  \item{kpar}{the list of hyper-parameters (kernel parameters).
    This is a list which contains the parameters to be used with the
    kernel function. For valid parameters for existing kernels are :
    \itemize{
      \item \code{sigma} inverse kernel width for the Radial Basis
      kernel function "rbfdot" and the Laplacian kernel "laplacedot".
      \item \code{degree, scale, offset} for the Polynomial kernel "polydot"
      \item \code{scale, offset} for the Hyperbolic tangent kernel
      function "tanhdot"
      \item \code{sigma, order, degree} for the Bessel kernel "besseldot". 
      \item \code{sigma, degree} for the ANOVA kernel "anovadot".
    }
    Hyper-parameters for user defined kernels can be passed through the
    kpar parameter as well. In the case of a Radial Basis kernel function (Gaussian)
  kpar can also be set to the string "automatic" which uses the heuristics in 
  \code{sigest} to calculate a good \code{sigma} value for the data.}
  \item{C}{cost of constraints violation (default: 1)---it is the
    `C'-constant of the regularization term in the Lagrange formulation.}
  \item{nu}{parameter needed for \code{nu-classification},
    \code{one-classification}, and \code{nu-regression}. The \code{nu}
    parameter sets the upper bound on the training error and the lower
    bound on the fraction of data points to become Support Vectors (default: 0.2).}
  \item{epsilon}{epsilon in the insensitive-loss function used for
    \code{eps-regression} and \code{nu-regression} (default: 0.1)}
  \item{prob.model}{if set to \code{TRUE} a model for calculating class
    probabilities is fitted on output data created by performing a
    3-fold cross-validation on the training data. For details see
    references. (default: \code{FALSE})}
  \item{class.weights}{a named vector of weights for the different
    classes, used for asymmetric class sizes. Not all factor levels have
    to be supplied (default weight: 1). All components have to be named.}
  \item{cachesize}{cache memory in MB (default 40)}
  \item{tol}{tolerance of termination criterion (default: 0.001)}
 
  \item{shrinking}{option whether to use the shrinking-heuristics
    (default: \code{TRUE})}
  \item{cross}{if a integer value k>0 is specified, a k-fold cross
    validation on the training data is performed to assess the quality
    of the model: the accuracy rate for classification and the Mean
    Squared Error for regression}
  \item{fit}{indicates whether the fitted values should be computed
    and included in the model or not (default: \code{TRUE})}
  \item{\dots}{additional parameters for the low level fitting function}
  \item{subset}{An index vector specifying the cases to be used in the
          training sample.  (NOTE: If given, this argument must be
          named.)}
  \item{na.action}{A function to specify the action to be taken if \code{NA}s are
          found. The default action is \code{na.omit}, which leads to rejection of cases
          with missing values on any required variable. An alternative
	  is \code{na.fail}, which causes an error if \code{NA} cases
	  are found. (NOTE: If given, this argument must be named.)}
      }
    
    \value{
      An S4 object of class \code{"ksvm"} containing the fitted model,
  Accessor functions can be used to access the slots of the object (see
  examples) which include:
  \item{alpha}{The resulting support vectors, (alpha vector) (possibly scaled).}
  \item{alphaindex}{The index of the resulting support vectors in the data
    matrix. Note that this index refers to the pre-processed data (after
    the possible effect of \code{na.omit} and \code{subset})}
  \item{coefs}{The corresponding coefficients times the training labels.}
  \item{b}{The negative intercept.}
  \item{nSV}{The number of Support Vectors}
  \item{error}{Training error}
  \item{cross}{Cross validation error, (when cross > 0)}
}

  
\details{For multiclass-classification with k levels, k>2, \code{ksvm} uses the
  `one-against-one'-approach, in which k(k-1)/2 binary classifiers are
  trained; the appropriate class is found by a voting scheme.\cr
  If the predictor variables include factors, the formula interface must be used to get a
  correct model matrix.
  The predict function can return probabilistic output (probability
  matrix) in the case of
  classification by setting the \code{type} parameter to "probabilities".
  
}
\note{Data is scaled internally, usually yielding better results.}
\references{
  \itemize{
    \item
      Chang, Chih-Chung and Lin, Chih-Jen:\cr
      \emph{LIBSVM: a library for Support Vector Machines}\cr
      \url{http://www.csie.ntu.edu.tw/~cjlin/libsvm}

     \item
      Exact formulations of models, algorithms, etc. can be found in the
      document:\cr
      Chang, Chih-Chung and Lin, Chih-Jen:\cr
      \emph{LIBSVM: a library for Support Vector Machines}\cr
      \url{http://www.csie.ntu.edu.tw/~cjlin/papers/libsvm.ps.gz}
   
     \item
     J. Platt\cr
     \emph{Probabilistic outputs for support vector machines and comparison to regularized likelihood methods} \cr
     Advances in Large Margin Classifiers, A. Smola, P. Bartlett, B. Schoelkopf and D. Schuurmans, Eds. Cambridge, MA: MIT Press, 2000.\cr
     \url{http://citeseer.nj.nec.com/platt99probabilistic.html}
     
    \item
    H.-T. Lin, C.-J. Lin and R. C. Weng\cr
    \emph{A note on Platt's probabilistic outputs for support vector machines}\cr
    \url{http://www.csie.ntu.edu.tw/~cjlin/papers/plattprob.ps}
    
  \item
     C.-W. Hsu and C.-J. Lin \cr
     \emph{A comparison on methods for multi-class support vector machines}\cr
     IEEE Transactions on Neural Networks, 13(2002) 415-425.\cr
     \url{http://www.csie.ntu.edu.tw/~cjlin/papers/multisvm.ps.gz}

     \item
     K. Crammer, Y. Singer\cr
     \emph{On the learnability and design of output codes for multiclass prolems}\cr
     Computational Learning Theory, 35-46, 2000.\cr
     \url{http://www.cs.huji.ac.il/~kobics/publications/mlj01.ps.gz}
  
  }
}
\author{
  Alexandros Karatzoglou (SMO optimizers in C/C++ by Chih-Chung Chang & Chih-Jen Lin)\cr
  \email{alexandros.karatzoglou@ci.tuwien.ac.at}
}
\seealso{\code{\link{predict.ksvm}}, \code{\link{couple}} }
  
\keyword{methods}
\keyword{regression}
\keyword{nonlinear}
\keyword{classif}

\examples{

## simple example using the spam data set
data(spam)


## create test and training set
index <- sample(1:dim(spam)[1])
spamtrain <- spam[index[1:floor(2 * dim(spam)[1]/3)], ]
spamtest <- spam[index[((2 * ceiling(dim(spam)[1]/3)) + 1):dim(spam)[1]], ]

## train a support vector machine
filter <- ksvm(type~.,data=spamtrain,kernel="rbfdot",kpar=list(sigma=0.05),C=5,cross=3)
filter

## predict mail type on the test set
mailtype <- predict(filter,spamtest[,-58])

## Check results
table(mailtype,spamtest[,58])


## Another example with the famous iris data
data(iris)

## Create a kernel function using the build in rbfdot function
rbf <- rbfdot(sigma=0.1)
rbf

## train a support vector machine
irismodel <- ksvm(Species~.,data=iris,kernel=rbf,C=10,prob.model=TRUE)

irismodel

## get fitted values
fit(irismodel)

## Test on the training set with probabilities as output
predict(irismodel, iris[,-5], type="probabilities")


## regression
# create data
x <- seq(-20,20,0.1)
y <- sin(x)/x + rnorm(401,sd=0.03)

# train support vector machine
regm <- ksvm(x,y,epsilon=0.01,kpar=list(sigma=16),cross=3)
plot(x,y,type="l")
lines(x,predict(regm,x),col="red")
}

\eof
\name{predict.ksvm}
\alias{predict.ksvm}
\alias{predict,ksvm-method}
\title{predict method for support vector object}


\description{Prediction of test data using support vector machines}


\usage{
\S4method{predict}{ksvm}(object, newdata, type = "response", coupler = "minpair")
}

\arguments{

  \item{object}{an S4 object of class \code{ksvm} created by the
    \code{ksvm} function}
  \item{newdata}{a data frame or matrix containing new data}
  \item{type}{one of \code{response}, \code{probabilities} ,\code{votes}
    indicating the type of output: predicted values, matrix of class
    probabilities, or matrix of vote counts.}
  \item{coupler}{Coupling method used in the multiclass case, can be one
    of \code{minpair} or \code{pkpd} (see reference for more details).}

}

\value{
   If \code{type(object)} is \code{C-classification},
     \code{nu-classification} or \code{spoc-classification}
     the vector returned depends on the argument \code{type}:
     
     \item{response}{predicted classes (the classes with majority vote).}

     \item{probabilities}{matrix of class probabilities (one column for each class and
       one row for each input).}

     \item{votes}{matrix of vote counts (one column for each class and one row
       for each new input)}
     
     If \code{type(object)} is \code{eps-regression},or
     \code{nu-regression} a vector of predicted values is returned.
     If \code{type(object)} is \code{one-classification} a vector of
     logical values is returned.
   }


   \references{
 \itemize{
     \item
       T.F. Wu, C.J. Lin, R.C. Weng. \cr
       \emph{Probability estimates for Multi-class Classification by
	 Pairwise Coupling}\cr
        \url{http://www.csie.ntu.edu.tw/~cjlin/papers/svmprob/svmprob.pdf}

      \item
	H.T. Lin, C.J. Lin, R.C. Weng\cr
	\emph{A note on Platt's probabilistic outputs for support vector
	  machines}\cr
	\url{http://www.csie.ntu.edu.tw/~cjlin/papers/plattprob.ps}
    }
}
\author{Alexandros Karatzoglou\cr
  \email{alexandros.karatzoglou@ci.tuwien.ac.at}}
   
\keyword{methods}
\keyword{regression}
\keyword{classif}


\examples{

## example using the spam data set
data(spam)
## create test and training set
traindex <- sample(1:dim(spam)[1],2*dim(spam)[1]/3)
spamtrain <- spam[traindex, ]
spamtest <- spam[-traindex, ]

## train a support vector machine
filter <-
ksvm(type~.,data=spamtrain,kernel="rbfdot",kpar=list(sigma=0.05),C=5,cross=3,prob.model=TRUE)
filter

## predict mail type probabilities on the test set
mailtype <- predict(filter,spamtest,type="probabilities")
mailtype[c(1:10,1000:1010),]

}


\eof
\name{ranking-class}
\docType{class}
\alias{ranking-class}
\alias{edgegraph}
\alias{convergence}
\alias{convergence,ranking-method}
\alias{edgegraph,ranking-method}
\alias{show,ranking-method}

\title{Class "ranking"}
\description{Object of the class \code{"ranking"} are created from the
  \code{ranking} function and extend the class \code{matrix}}
\section{Objects from the Class}{

Objects can be created by calls of the form \code{new("ranking", ...)}.

}
\section{Slots}{
  \describe{
    \item{\code{.Data}:}{Object of class \code{"matrix"} containing the
      data ranking and scores}
    \item{\code{convergence}:}{Object of class \code{"matrix"}
      containing the convergence matrix}
    \item{\code{edgegraph}:}{Object of class \code{"matrix"} containing
      the edgegraph}
  }
}
\section{Extends}{
Class \code{"matrix"}, directly.
}
\section{Methods}{
  \describe{
    \item{show}{\code{signature(object = "ranking")}: displays the
      ranking score matrix}
  }
}

\author{Alexandros Karatzoglou \cr
\email{alexandros.karatzoglou@ci.tuwien.ac.at}
}

\seealso{
  \code{\link{ranking}}
}
\examples{
data(spirals)

## create data set to be ranked
ran<-spirals[rowSums(abs(spirals)<0.55)==2,]

## rank points according to "relevance" to point 54 (up left)
ranked<-ranking(ran,54,kernel="rbfdot",kpar=list(sigma=100),edgegraph=TRUE)

ranked
edgegraph(ranked)[1:10,1:10]
}
\keyword{classes}

\eof
\name{ranking}
\alias{ranking}
\alias{ranking,matrix-method}
\title{Ranking}
\description{
 A universal ranking algorithm which assigns importance/ranking to data points
 given a query.
}
\usage{
\S4method{ranking}{matrix}(x, y,  kernel ="rbfdot", kpar = list(sigma = 1),  scale = TRUE,
alpha = 0.99, iterations = 600, edgegraph = FALSE, convergence = FALSE ,...)
}

\arguments{
  \item{x}{a matrix containing the data to be ranked}
  \item{y}{The index of the query point in the data matrix or a vector
    of length equal to the rows of the data matrix having a one at the
    index of the query points index and zero at all the other points.}

 
    \item{kernel}{the kernel function used in training and predicting.
    This parameter can be set to any function, of class kernel, which computes a dot product between two
    vector arguments. kernlab provides the most popular kernel functions
    which can be used by setting the kernel parameter to the following
    strings:
    \itemize{
      \item \code{rbfdot} Radial Basis kernel function "Gaussian"
      \item \code{polydot} Polynomial kernel function
      \item \code{vanilladot} Linear kernel function
      \item \code{tanhdot} Hyperbolic tangent kernel function
      \item \code{laplacedot} Laplacian kernel function
      \item \code{besseldot} Bessel kernel function
      \item \code{anovadot} ANOVA RBF kernel function
    }
    The kernel parameter can also be set to a user defined function of
    class kernel by passing the function name as an argument.
  }

  \item{kpar}{the list of hyper-parameters (kernel parameters).
    This is a list which contains the parameters to be used with the
    kernel function. For valid parameters for existing kernels are :
    \itemize{
      \item \code{sigma} inverse kernel width for the Radial Basis
      kernel function "rbfdot" and the Laplacian kernel "laplacedot".
      \item \code{degree, scale, offset} for the Polynomial kernel "polydot"
      \item \code{scale, offset} for the Hyperbolic tangent kernel
      function "tanhdot"
      \item \code{sigma, order, degree} for the Bessel kernel "besseldot".
      \item \code{sigma, degree} for the ANOVA kernel "anovadot".
    }
    Hyper-parameters for user defined kernels can be passed through the
    kpar parameter as well.}
  \item{scale}{If TRUE the data matrix columns are scaled to zero mean
    and unit variance.}
  \item{alpha}{ The \code{alpha} parameter takes values between 0 and 1
    and is used to control the authoritative scores received from the
    unlabeled points. For 0 no global structure is found the algorithm
    ranks the points similarly to the original distance metric.}
  \item{iterations}{Maximum number of iterations}
  \item{edgegraph}{Construct edgegraph (only supported with the RBF
    kernel)}
  \item{convergence}{Include convergence matrix in results}
  \item{\dots}{Additional arguments}
}
\details{
A simple universal ranking algorithm which exploits the intrinsic
global geometric structure of the data. In many real world
applications this should be superior to a local method in which the data
are simply ranked by pairwise Euclidean distances.
Firstly a weighted network is defined on the data and an authoritative
score is assigned to each query. The query points act as source nodes
that continually pump their authoritative scores to the remaining points
via the weighted network and the remaining points further spread the
scores they received to their neighbors. This spreading process is
repeated until convergence and the points are ranked according to their
score at the end of the iterations.
}
\value{
  An S4 object of class \code{ranking} which extends the \code{matrix}
  class.
  The first column of the returned matrix contains the original index of
  the points in the data matrix the second column contains the final
  score received by each point and the third column the ranking of the point.
  The object contains the following slots :
  \item{edgegraph}{Containing the edgegraph of the data points. }
  \item{convergence}{Containing the convergence matrix}
}
\references{
  D. Zhou, J. Weston, A. Gretton, O. Bousquet, B. Schoelkopf \cr
  \emph{Ranking on Data Manifolds}\cr
  Advances in Neural Information Processing Systems 16.\cr
  MIT Press Cambridge Mass. 2004 \cr
  \url{http://www.kyb.mpg.de/publications/pdfs/pdf2334.pdf}
}

\author{Alexandros Karatzoglou \cr
\email{alexandros.karatzoglou@ci.tuwien.ac.at}}

\seealso{ \code{\link{ranking-class}}, \code{\link{specc}} }
\examples{
data(spirals)
## create data set to be ranked
ran<-spirals[rowSums(abs(spirals)<0.55)==2,]

## rank points according to "relevance" to point 54 (up left)
ranked<-ranking(ran,54,kernel="rbfdot",kpar=list(sigma=100),edgegraph=TRUE)
ranked[54,2] <-  max(ranked[-54,2])
plot(ran,col=hsv(ranked[,2]/ranked[54,2],1,1))
}
\keyword{cluster}
\keyword{classif}

\eof
\name{rvm-class}
\docType{class}
\alias{rvm-class}
\alias{RVindex}
\alias{mlike}
\alias{nvar}
\alias{RVindex,rvm-method}
\alias{alpha,rvm-method}
\alias{cross,rvm-method}
\alias{error,rvm-method}
\alias{fit,rvm-method}
\alias{kcall,rvm-method}
\alias{kernelf,rvm-method}
\alias{kpar,rvm-method}
\alias{lev,rvm-method}
\alias{mlike,rvm-method}
\alias{nvar,rvm-method}
\alias{type,rvm-method}
\alias{xmatrix,rvm-method}
\alias{ymatrix,rvm-method}

\title{Class "rvm"}
\description{Relevance Vector Machine Class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("rvm", ...)}.
or by calling the \code{rvm} function.
}
\section{Slots}{
  \describe{

    \item{\code{tol}:}{Object of class \code{"numeric"} contains
      tolerance of termination critiria used.}
    \item{\code{kernelf}:}{Object of class \code{"function"} contains
      the kernel function used }
    \item{\code{kpar}:}{Object of class \code{"list"} contains the
      hyperparameter used}
    \item{\code{kcall}:}{Object of class \code{"ANY"} contains the
      function call}
    \item{\code{type}:}{Object of class \code{"character"} contains type
    of problem}
    \item{\code{kterms}:}{Object of class \code{"ANY"}  containing the
      terms representation of the symbolic model used (when using a
      formula interface)}
    \item{\code{xmatrix}:}{Object of class \code{"matrix"} contains the data
      matrix used during computation}
    \item{\code{ymatrix}:}{Object of class \code{"ANY"} contains the
      response matrix}
    \item{\code{fit}:}{Object of class \code{"ANY"} with the fitted
      values, (predict on trianing set).}
    \item{\code{lev}:}{Object of class \code{"vector"} contains the
      levels of the response (in classification)}
    \item{\code{nclass}:}{Object of class \code{"numeric"} contains the
      number of classes (in classification)}
    \item{\code{alpha}:}{Object of class \code{"ANY"} containing the the
    resulting alpha vector}
    \item{\code{nvar}:}{Object of class \code{"numeric"} containing the
      calculated variance (in case of regression)}
    \item{\code{mlike}:}{Object of class \code{"numeric"} containing the
    computed maximum likelihood}
    \item{\code{RVindex}:}{Object of class \code{"vector"} containing
      the indexes of the resulting relevance vectors }
    \item{\code{nRV}:}{Object of class \code{"numeric"} containing the
      number of relevance vectors}
    \item{\code{cross}:}{Object of class \code{"ANY"} containing the
      relusting cross validation error }
    \item{\code{error}:}{Object of class \code{"numeric"} containing the
    training error}
    \item{\code{n.action}:}{Object of class \code{"ANY"} containing the
      action performed on NA}

  }
}
\section{Methods}{
  \describe{
    \item{RVindex}{\code{signature(object = "rvm")}: returns the index
      of the relevance vectors }
    \item{alpha}{\code{signature(object = "rvm")}: returns the resulting
    alpha vector}
    \item{cross}{\code{signature(object = "rvm")}: returns the resulting
    cross validation error}
    \item{error}{\code{signature(object = "rvm")}: returns the training
      error  }
    \item{fit}{\code{signature(object = "rvm")}: returns the fitted values }
    \item{kcall}{\code{signature(object = "rvm")}: returns the function call }
    \item{kernelf}{\code{signature(object = "rvm")}: returns the used
      kernel function }
    \item{kpar}{\code{signature(object = "rvm")}: returns the parameters
    of the kernel function}
    \item{lev}{\code{signature(object = "rvm")}: returns the levels of
      the response (in classification)}
    \item{mlike}{\code{signature(object = "rvm")}: returns the estimated
    maiximum likelihood}
    \item{nvar}{\code{signature(object = "rvm")}: returns the calculated
    variance (in regression)}
    \item{type}{\code{signature(object = "rvm")}: returns the type of problem}
    \item{xmatrix}{\code{signature(object = "rvm")}: returns the data
      mmatrix used during computation}
    \item{ymatrix}{\code{signature(object = "rvm")}: returns the used response }
  }
}

\author{Alexandros Karatzoglou\cr \email{alexandros.karatzoglou@ci.tuwien.ac.at}}




\seealso{
  \code{\link{rvm}}, 
   \code{\link{ksvm-class}}
}

\examples{

# create data
x <- seq(-20,20,0.1)
y <- sin(x)/x + rnorm(401,sd=0.05)

# train relevance vector machine
foo <- rvm(x, y)
foo

alpha(foo)
RVindex(foo)
fit(foo)
kernelf(foo)
nvar(foo)

## show slots
slotNames(foo)

}
\keyword{classes}

\eof
\name{rvm}
\alias{rvm}
\alias{rvm-methods}
\alias{rvm,formula-method}
\alias{rvm,vector-method}
\alias{rvm,matrix-method}
\alias{show,rvm-method}
\alias{predict,rvm-method}
\title{Relevance Vector Machine }

\description{
  The Relevance Vector Machine is a Bayesian model for regression and
  classification of identical functional form to the support vector
  machine.
  The \code{rvm} function currently supports only regression.
}
\usage{
\S4method{rvm}{formula}(x, data=NULL, ..., subset, na.action = na.omit)

\S4method{rvm}{vector}(x, ...)

\S4method{rvm}{matrix}(x, y, type="regression", kernel="rbfdot", kpar=list(sigma=0.1),
alpha=1, var=0.1, var.fix=FALSE, iterations=100, verbosity=0, tol=
.Machine$double.eps,minmaxdiff = 1e-3, cross = 0, fit =TRUE, subset,
na.action = na.omit,...) 

}



\arguments{

 \item{x}{a symbolic description of the model to be fit. Note, that an
          intercept is always included, whether given in the formula or
          not. When not using a formula x is a matrix or vector
	  containg the variables in the model.}
  \item{data}{an optional data frame containing the variables in the model.
          By default the variables are taken from the environment which
          `rvm' is called from.}
	  
  \item{y}{a response vector with one label for each row/component of \code{x}. Can be either
    a factor (for classification tasks) or a numeric vector (for
    regression).}
  \item{type}{\code{rvm} can only be used for regression at the moment.}


  \item{kernel}{the kernel function used in training and predicting.
    This parameter can be set to any function, of class kernel, which computes a dot product between two
    vector arguments. kernlab provides the most popular kernel functions
    which can be used by setting the kernel parameter to the following
    strings:
    \itemize{
      \item \code{rbfdot} Radial Basis kernel function "Gaussian"
      \item \code{polydot} Polynomial kernel function
      \item \code{vanilladot} Linear kernel function
      \item \code{tanhdot} Hyperbolic tangent kernel function
      \item \code{laplacedot} Laplacian kernel function
      \item \code{besseldot} Bessel kernel function
      \item \code{anovadot} ANOVA RBF kernel function
    }
    The kernel parameter can also be set to a user defined function of
    class kernel by passing the function name as an argument.
  }

  \item{kpar}{the list of hyper-parameters (kernel parameters).
    This is a list which contains the parameters to be used with the
    kernel function. For valid parameters for existing kernels are :
    \itemize{
      \item \code{sigma} inverse kernel width for the Radial Basis
      kernel function "rbfdot" and the Laplacian kernel "laplacedot".
      \item \code{degree, scale, offset} for the Polynomial kernel "polydot"
      \item \code{scale, offset} for the Hyperbolic tangent kernel
      function "tanhdot"
      \item \code{sigma, order, degree} for the Bessel kernel "besseldot". 
      \item \code{sigma, degree} for the ANOVA kernel "anovadot".
    }

    Hyper-parameters for user defined kernels can be passed through the
    kpar parameter as well.}

  \item{alpha}{The initial alpha vector. Can be either a vector of
    length equal to the number of data points or a single number.}

  \item{var}{the initial noise variance}

  \item{var.fix}{Keep noise variance fix during iterations (default: FALSE)}

  \item{iterations}{Number of iterations allowed (default: 100)} 
  \item{tol}{tolerance of termination criterion}
  \item{minmaxdiff}{termination criteria. Stop when max difference is
    equall to this parameter (default:1e-3) }
  \item{verbosity}{print information on algorithm convergence (default
    = FALSE)}
  \item{fit}{indicates whether the fitted values should be computed and
          included in the model or not (default: TRUE)}
	\item{cross}{if a integer value k>0 is specified, a k-fold cross
          validation on the training data is performed to assess the
          quality of the model: the Mean Squared Error for regression}

	\item{subset}{An index vector specifying the cases to be used in the
          training sample.  (NOTE: If given, this argument must be
          named.)}
  \item{na.action}{A function to specify the action to be taken if \code{NA}s are
          found. The default action is \code{na.omit}, which leads to rejection of cases
          with missing values on any required variable. An alternative
	  is \code{na.fail}, which causes an error if \code{NA} cases
	  are found. (NOTE: If given, this argument must be named.)}
	

  \item{\dots}{ additional parameters}
}
\details{ The Relevance Vector Machine typically leads to sparser models
  then the SVM. It also performs better in many cases (specially in
  regression). 
  }
\value{
  An S4 object of class "rvm" containing the fitted model.
  Accessor functions can be used to access the slots of the
  object which include :
  
  
  \item{alpha}{The resulting relevance vectors}
  \item{alphaindex}{ The index of the resulting relevance vectors in the data
    matrix}
  \item{nRV}{Number of relevance vectors}
  \item{RVindex}{The indexes of the relevance vectors}
  \item{error}{Training error (if fit == TRUE)}
  
  ...
}
\references{
 \item
      Tipping, M. E.\cr
      \emph{Sparse Bayesian learning and the relevance vector machine}\cr
      Journal of Machine Learning Research  1, 211-244\cr
      \url{http://www.jmlr.org/papers/volume1/tipping01a/tipping01a.pdf}
    }
\author{ Alexandros Karatzoglou \cr
\email{alexandros.karatzoglou@ci.tuwien.ac.at}}

\seealso{ \code{\link{ksvm}}}
\examples{
# create data
x <- seq(-20,20,0.1)
y <- sin(x)/x + rnorm(401,sd=0.05)

# train relevance vector machine
foo <- rvm(x, y)
foo
# print relevance vectors
alpha(foo)
RVindex(foo)

# predict and plot
ytest <- predict(foo, x)
plot(x, y, type ="l")
lines(x, ytest, col="red")
}
\keyword{regression}
\keyword{nonlinear}

\eof
\name{sigest}
\alias{sigest}
\alias{sigest,formula-method}
\alias{sigest,matrix-method}

\title{Hyperparameter estimation for the Gaussian Radial Basis kernel}
\description{
 Given a range of values for the "sigma" inverse width parameter in the Gaussian Radial Basis kernel
 for use with Support Vector Machines. The estimation is based on the
 data to be used.  
}
\usage{
\S4method{sigest}{formula}(x, data=NULL, frac = 0.25, na.action = na.omit, scaled = TRUE)
\S4method{sigest}{matrix}(x, frac = 0.25, scaled = TRUE, na.action = na.omit)
}

\arguments{
  \item{x}{a symbolic description of the model upon the estimation is
    based. When not using a formula x is a matrix or vector
    containing the data}
 \item{data}{an optional data frame containing the variables in the model.
          By default the variables are taken from the environment which
          `ksvm' is called from.}

\item{frac}{Fraction of data to use for estimation. By default a quarter
  of the data is used to estimate the range of the sigma hyperparameter.}
	
	\item{scaled}{A logical vector indicating the variables to be
    scaled. If \code{scaled} is of length 1, the value is recycled as
    many times as needed and all non-binary variables are scaled.
    Per default, data are scaled internally to zero mean and unit
    variance
    (since this the default action in \code{ksvm} as well). The center and scale
    values are returned and used for later predictions. }
  \item{na.action}{A function to specify the action to be taken if \code{NA}s are
          found. The default action is \code{na.omit}, which leads to rejection of cases
          with missing values on any required variable. An alternative
	  is \code{na.fail}, which causes an error if \code{NA} cases
	  are found. (NOTE: If given, this argument must be named.)}
 
}



\details{
\code{sigest} estimates the range of values for the sigma parameter
which would return good results when used with a Support Vector
Machine (\code{ksvm}). The estimation is based upon the 0.1 and 0.9 quantile 
of \eqn{\|x -x'\|^2}. Basicly any value in between those two bounds will
produce good results.
}
\value{
  Returns a vector of length 2 defining the range (upper bound and lower bound) of
  the sigma hyperparameter. 
  }
\references{ B. Caputo, K. Sim, F. Furesjo, A. Smola, \cr
\emph{Appearance-based object recognition using SVMs: which kernel should I use?}\cr
Proc of NIPS workshop on Statitsical methods for computational experiments in visual processing and computer vision, Whistler, 2002.
}
\author{Alexandros Karatzoglou \cr 
  \email{alexandros.karatzoglou@ci.tuwien.ac.at}}



\seealso{\code{\link{ksvm}}}
}
\examples{

## estimate good sigma values for spam
data(spam)
srange <- sigest(type~.,data = spam)
srange
## Use that to build a spam filter
s <- sum(srange)/2
s
## create test and training set
index <- sample(1:dim(spam)[1])
spamtrain <- spam[index[1:floor(2 * dim(spam)[1]/3)], ]
spamtest <- spam[index[((2 * ceiling(dim(spam)[1]/3)) + 1):dim(spam)[1]], ]

## train a support vector machine
filter <- ksvm(type~.,data=spamtrain,kernel="rbfdot",kpar=list(sigma = s),C=50,cross=3)
filter

## predict mail type on the test set
mailtype <- predict(filter,spamtest[,-58])

## Check results
table(mailtype,spamtest[,58])

}
\keyword{classif}
\keyword{regression}

\eof
\name{spam}
\alias{spam}
\title{Spam E-mail Database}
\description{A data set collected at Hewlett-Packard Labs, that classifies 4601
e-mails as spam or non-spam. In addition to this class label there are 57
variables indicating the frequency of certain words and characters in the
e-mail.}
\usage{data(spam)}
\format{A data frame with 4601 observations and 58 variables.

The first 48 variables contain the frequency of the variable name
(e.g., business) in the e-mail. If the variable name starts with num (e.g.,
num650) the it indicates the frequency of the corresponding number (e.g., 650).
The variables 49-54 indicate the frequency of the characters `;', `(', `[', `!',
`\$', and `\#'. The variables 55-57 contain the average, longest 
and total run-length of captial letters. Variable 58 indicates the type of the
mail and is either \code{"nonspam"} or \code{"spam"}, i.e. unsolicited
commercial e-mail.}

\details{
The data set contains 2788 e-mails classified as \code{"nonspam"} and 1813
classified as \code{"spam"}.

The ``spam'' concept is diverse: advertisements for products/web
sites, make money fast schemes, chain letters, pornography...
This collection of spam e-mails came from the collectors' postmaster and
individuals who had filed spam.  The collection of non-spam
e-mails came from filed work and personal e-mails, and hence
the word 'george' and the area code '650' are indicators of
non-spam.  These are useful when constructing a personalized
spam filter.  One would either have to blind such non-spam
indicators or get a very wide collection of non-spam to
generate a general purpose spam filter.
}
\source{
\itemize{
\item Creators: Mark Hopkins, Erik Reeber, George Forman, Jaap Suermondt at
Hewlett-Packard Labs, 1501 Page Mill Rd., Palo Alto, CA 94304
\item Donor: George Forman (gforman at nospam hpl.hp.com)  650-857-7835
}
These data have been taken from the UCI Repository Of Machine Learning
Databases at \url{http://www.ics.uci.edu/~mlearn/MLRepository.html}}
\references{
T. Hastie, R. Tibshirani, J.H. Friedman. \emph{The Elements of Statistical
Learning.} Springer, 2001.
}

\keyword{datasets}

\eof
\name{specc-class}
\docType{class}
\alias{specc-class}
\alias{centers}
\alias{size}
\alias{withinss}
\alias{centers,specc-method}
\alias{withinss,specc-method}
\alias{size,specc-method}
\alias{kernelf,specc-method}


\title{Class "specc"}
\description{ The Spectral Clustering Class}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("specc", ...)}.
    or by calling the function \code{specc}. 
}
\section{Slots}{
  \describe{
    \item{\code{centers}:}{Object of class \code{"matrix"} containing
      the cluser centers}
    \item{\code{size}:}{Object of class \code{"vector"} containing the
      number of points in each  cluster}
    \item{\code{withinss}:}{Object of class \code{"vector"} containing
      the within-cluster sum of squares for each cluster}
    \item{\code{kernelf}}{Object of class \code{kernel} containing the
      used kernel function.}
  }
}
\section{Methods}{
  \describe{
    \item{centers}{\code{signature(object = "specc")}: returns the
      cluster centers}
    \item{withinss}{\code{signature(object = "specc")}: returns the
      within-cluster sum of squares for each cluster}
    \item{size}{\code{signature(object = "specc")}: returns the number
      of points in each cluster }

  }
}

\author{Alexandros Karatzoglou\cr \email{alexandros.karatzoglou@ci.tuwien.ac.at}}



\seealso{
  \code{\link{specc}}, 
   \code{\link{kpca-class}} 
}
\examples{
## Cluster the spirals data set.
data(spirals)

sc <- specc(spirals, centers=2)

centers(sc)
size(sc)
}
\keyword{classes}

\eof
\name{specc}
\alias{specc}
\alias{specc,matrix-method}
\alias{specc,formula-method}
\alias{show,specc-method}
\title{Spectral Clustering}
\description{
A spectral clustering  algorithm. This algorithm clusters points using
eigenvectors of kernel matrixes derived from the data.  
}
\usage{
\S4method{specc}{formula}(x, data = NULL, na.action = na.omit, ...)

\S4method{specc}{matrix}(x, centers, kernel = "rbfdot", kpar =
list(sigma = 0.1), iterations = 200, mod.sample = 0.6, na.action = na.omit, ...)
}

\arguments{
  \item{x}{the matrix of data to be clustered or a symbolic
    description of the model to be fit.}
  \item{data}{an optional data frame containing the variables in the model.
    By default the variables are taken from the environment which
    `specc' is called from.}
  \item{centers}{Either the number of clusters or a set of initial cluster
    centers. If the first, a random set of rows in the eigenvectors
    matrix are chosen as the initial centers.}


\item{kernel}{the kernel function used in training and predicting.
    This parameter can be set to any function, of class kernel, which computes a dot product between two
    vector arguments. kernlab provides the most popular kernel functions
    which can be used by setting the kernel parameter to the following
    strings:
    \itemize{
      \item \code{rbfdot} Radial Basis kernel function "Gaussian"
      \item \code{polydot} Polynomial kernel function
      \item \code{vanilladot} Linear kernel function
      \item \code{tanhdot} Hyperbolic tangent kernel function
      \item \code{laplacedot} Laplacian kernel function
      \item \code{besseldot} Bessel kernel function
      \item \code{anovadot} ANOVA RBF kernel function
    }
    The kernel parameter can also be set to a user defined function of
    class kernel by passing the function name as an argument.
  }

  \item{kpar}{the list of hyper-parameters (kernel parameters).
    This is a list which contains the parameters to be used with the
    kernel function. For valid parameters for existing kernels are :
    \itemize{
      \item \code{sigma} inverse kernel width for the Radial Basis
      kernel function "rbfdot" and the Laplacian kernel "laplacedot".
      \item \code{degree, scale, offset} for the Polynomial kernel "polydot"
      \item \code{scale, offset} for the Hyperbolic tangent kernel
      function "tanhdot"
      \item \code{sigma, order, degree} for the Bessel kernel "besseldot". 
      \item \code{sigma, degree} for the ANOVA kernel "anovadot".
    }
    
    Hyper-parameters for user defined kernels can be passed through the
    kpar parameter as well.}
	
 \item{mod.sample} {Proportion of data to use when estimating sigma default 0.6}	

  \item{iterations}{The maximum number of iterations allowed. }

  \item{na.action}{ The action to perform on NA}

  \item{\dots}{additional parameters}
    
}
\details{
 In Spectral Clustering one uses the top \code{k} (number of clusters) eigenvectors of a matrix derived
 from the distance between points. Very good results are obtained by
 using a standard clustering technique
 to cluster the resulting eigenvector matrixes. 
}
\value{
 An S4 object of class \code{specc} wich extends the class \code{vector}
 containing integers indicating the cluster to which
 each point is allocated. The following slots contain useful information
 
  \item{centers}{A matrix of cluster centers.}
  \item{size}{The number of point in each cluster}
  \item{withinss}{The within-cluster sum of squares for each cluster}
  \item{kernelf}{The kernel function used}
}
\references{
  Andrew Y. Ng, Michael I. Jordan, Yair Weiss\cr
  \emph{On Spectral Clustering: Analysis and an Algorithm}\cr
  Neural Information Processing Symposium 2001\cr
  \url{http://www.nips.cc/NIPS2001/papers/psgz/AA35.ps.gz}

}
\author{ Alexandros Karatzoglou \cr \email{alexandros.karatzoglou@ci.tuwien.ac.at}
}


\seealso{ \code{\link{kpca}}, \code{\link{kcca}} }
\examples{
## Cluster the spirals data set.
data(spirals)

sc <- specc(spirals, centers=2)

sc
centers(sc)
size(sc)
withinss(sc)

plot(spirals, col=sc)

}
\keyword{cluster}


\eof
\name{spirals}
\alias{spirals}
\title{Spirals Dataset}
\description{A toy data set representing
two spirals with Gaussian noise. The data was created with the \code{mlbench.spirals}
function in \code{mlbench}.
}
\usage{data(spirals)}
\format{
A matrix with 300 observations and 2 variables.
}

\examples{
data(spirals)
plot(spirals)
}
\keyword{datasets}

\eof
\name{ticdata}
\alias{ticdata}
\title{The Insurance Company Data}
\description{
This data set used in the CoIL 2000 Challenge contains information on customers of an insurance
company. The data consists of 86 variables and includes product usage data and socio-demographic
data derived from zip area codes.
The data was collected to answer the following question: Can you
predict who would be interested in buying a caravan insurance policy and give an explanation why ?
}
\usage{data(ticdata)}
\format{

ticdata: Dataset to train and validate prediction models and build a description (9822
customer records). Each record consists of 86 attributes, containing
sociodemographic data (attribute 1-43) and product ownership (attributes 44-86).
The sociodemographic data is derived from zip codes. All customers
living in areas with the same zip code have the same sociodemographic
attributes. Attribute 86, \code{CARAVAN:Number of mobile home policies}, is the target variable.

Data Format

  
\tabular{rlll}{
\tab 1 \tab \code{STYPE} \tab Customer Subtype\cr
\tab 2 \tab \code{MAANTHUI} \tab Number of houses 1 - 10\cr
\tab 3 \tab \code{MGEMOMV} \tab Avg size household 1 - 6\cr
\tab 4 \tab \code{MGEMLEEF} \tab Average age\cr
\tab 5 \tab \code{MOSHOOFD} \tab Customer main type\cr
\tab 6 \tab \code{MGODRK} \tab Roman catholic   \cr
\tab 7 \tab \code{MGODPR} \tab Protestant ...   \cr
\tab 8 \tab \code{MGODOV} \tab Other religion    \cr
\tab 9 \tab \code{MGODGE} \tab No religion      \cr
\tab 10 \tab \code{MRELGE} \tab Married        \cr
\tab 11 \tab \code{MRELSA} \tab Living together  \cr
\tab 12 \tab \code{MRELOV} \tab Other relation   \cr
\tab 13 \tab \code{MFALLEEN} \tab Singles         \cr
\tab 14 \tab \code{MFGEKIND} \tab Household without children    \cr
\tab 15 \tab \code{MFWEKIND} \tab Household with children \cr
\tab 16 \tab \code{MOPLHOOG} \tab High level education    \cr
\tab 17 \tab \code{MOPLMIDD} \tab Medium level education  \cr
\tab 18 \tab \code{MOPLLAAG} \tab Lower level education  \cr
\tab 19 \tab \code{MBERHOOG} \tab High status      \cr
\tab 20 \tab \code{MBERZELF} \tab Entrepreneur       \cr
\tab 21 \tab \code{MBERBOER} \tab Farmer            \cr
\tab 22 \tab \code{MBERMIDD} \tab Middle management  \cr
\tab 23 \tab \code{MBERARBG} \tab Skilled labourers  \cr
\tab 24 \tab \code{MBERARBO} \tab Unskilled labourers \cr
\tab 25 \tab \code{MSKA} \tab Social class A          \cr
\tab 26 \tab \code{MSKB1} \tab Social class B1        \cr
\tab 27 \tab \code{MSKB2} \tab Social class B2        \cr
\tab 28 \tab \code{MSKC} \tab Social class C           \cr
\tab 29 \tab \code{MSKD} \tab Social class D           \cr
\tab 30 \tab \code{MHHUUR} \tab Rented house        \cr
\tab 31 \tab \code{MHKOOP} \tab Home owners         \cr
\tab 32 \tab \code{MAUT1} \tab 1 car                \cr
\tab 33 \tab \code{MAUT2} \tab 2 cars                \cr
\tab 34 \tab \code{MAUT0} \tab No car   \cr
\tab 35 \tab \code{MZFONDS} \tab National Health Service    \cr
\tab 36 \tab \code{MZPART} \tab Private health insurance     \cr
\tab 37 \tab \code{MINKM30} \tab Income  >30.000      \cr
\tab 38 \tab \code{MINK3045} \tab Income 30-45.000    \cr
\tab 39 \tab \code{MINK4575} \tab Income 45-75.000    \cr
\tab 40 \tab \code{MINK7512} \tab Income 75-122.000   \cr
\tab 41 \tab \code{MINK123M} \tab Income <123.000    \cr
\tab 42 \tab \code{MINKGEM} \tab Average income       \cr
\tab 43 \tab \code{MKOOPKLA} \tab Purchasing power class  \cr
\tab 44 \tab \code{PWAPART} \tab Contribution private third party insurance  \cr
\tab 45 \tab \code{PWABEDR} \tab Contribution third party insurance (firms)  \cr
\tab 46 \tab \code{PWALAND} \tab Contribution third party insurane (agriculture) \cr
\tab 47 \tab \code{PPERSAUT} \tab Contribution car policies          \cr
\tab 48 \tab \code{PBESAUT} \tab Contribution delivery van policies  \cr
\tab 49 \tab \code{PMOTSCO} \tab Contribution motorcycle/scooter policies   \cr
\tab 50 \tab \code{PVRAAUT} \tab Contribution lorry policies             \cr
\tab 51 \tab \code{PAANHANG} \tab Contribution trailer policies         \cr
\tab 52 \tab \code{PTRACTOR} \tab Contribution tractor policies        \cr
\tab 53 \tab \code{PWERKT} \tab Contribution agricultural machines policies   \cr
\tab 54 \tab \code{PBROM} \tab Contribution moped policies       \cr
\tab 55 \tab \code{PLEVEN} \tab Contribution life insurances     \cr
\tab 56 \tab \code{PPERSONG} \tab Contribution private accident insurance policies \cr
\tab 57 \tab \code{PGEZONG} \tab Contribution family accidents insurance policies \cr
\tab 58 \tab \code{PWAOREG} \tab Contribution disability insurance policies \cr
\tab 59 \tab \code{PBRAND} \tab Contribution fire policies           \cr
\tab 60 \tab \code{PZEILPL} \tab Contribution surfboard policies    \cr
\tab 61 \tab \code{PPLEZIER} \tab Contribution boat policies      \cr
\tab 62 \tab \code{PFIETS} \tab Contribution bicycle policies       \cr
\tab 63 \tab \code{PINBOED} \tab Contribution property insurance policies   \cr
\tab 64 \tab \code{PBYSTAND} \tab Contribution social security insurance policies  \cr
\tab 65 \tab \code{AWAPART} \tab Number of private third party insurance 1 - 12   \cr
\tab 66 \tab \code{AWABEDR} \tab Number of third party insurance (firms) ...   \cr
\tab 67 \tab \code{AWALAND} \tab Number of third party insurane (agriculture)  \cr
\tab 68 \tab \code{APERSAUT} \tab Number of car policies          \cr
\tab 69 \tab \code{ABESAUT} \tab Number of delivery van policies   \cr
\tab 70 \tab \code{AMOTSCO} \tab Number of motorcycle/scooter policies  \cr
\tab 71 \tab \code{AVRAAUT} \tab Number of lorry policies    \cr
\tab 72 \tab \code{AAANHANG} \tab Number of trailer policies  \cr
\tab 73 \tab \code{ATRACTOR} \tab Number of tractor policies  \cr
\tab 74 \tab \code{AWERKT} \tab Number of agricultural machines policies     \cr
\tab 75 \tab \code{ABROM} \tab Number of moped policies          \cr
\tab 76 \tab \code{ALEVEN} \tab Number of life insurances        \cr
\tab 77 \tab \code{APERSONG} \tab Number of private accident insurance policies   \cr
\tab 78 \tab \code{AGEZONG} \tab Number of family accidents insurance policies   \cr
\tab 79 \tab \code{AWAOREG} \tab Number of disability insurance policies         \cr
\tab 80 \tab \code{ABRAND} \tab Number of fire policies            \cr
\tab 81 \tab \code{AZEILPL} \tab Number of surfboard policies     \cr
\tab 82 \tab \code{APLEZIER} \tab Number of boat policies        \cr
\tab 83 \tab \code{AFIETS} \tab Number of bicycle policies         \cr
\tab 84 \tab \code{AINBOED} \tab Number of property insurance policies   \cr
\tab 85 \tab \code{ABYSTAND} \tab Number of social security insurance policies  \cr
\tab 86 \tab \code{CARAVAN} \tab Number of mobile home policies 0 - 1          \cr
}
Note: All the variables starting with M are zipcode variables. They give information on the
distribution of that variable, e.g. Rented house, in the zipcode area of
the customer.
}



\details{
  
  Information about the insurance company customers consists of 86
  variables and includes
  product usage data and socio-demographic data derived from zip area codes. The
  data was supplied by the Dutch data mining company Sentient Machine
  Research and is based on a real world business problem. The training
  set contains over 5000 descriptions of customers, including the
  information of whether or not they have a caravan insurance policy.
  The test set contains 4000 customers. The test and data set are merged in the
  ticdata set.
  More information about the data set and the CoIL 2000 Challenge along
  with publications based on the data set can be found at \url{http://www.liacs.nl/~putten/library/cc2000/}.
}
\source{
  \itemize{
    \item UCI KDD Archive:\url{http://kdd.ics.uci.edu} 
      \item Donor:  Sentient Machine Research \cr
    Peter van der Putten \cr
    Sentient Machine Research \cr
    Baarsjesweg 224 \cr
    1058 AA Amsterdam \cr
    The Netherlands \cr
    +31 20 6186927 \cr
    pvdputten@hotmail.com, putten@liacs.nl
  }
}
  \references{Peter van der Putten, Michel de Ruiter, Maarten van
    Someren  \emph{CoIL Challenge 2000 Tasks and Results: Predicting and
      Explaining Caravan Policy Ownership}\cr
    \url{http://www.liacs.nl/~putten/library/cc2000/}}
  

 



\keyword{datasets}

\eof
